# Copyright (c) 2023 Darren Erik Vengroff
"""Places in West Virginia."""


ACCOVILLE_CDP = "00196"
ADDISON_WEBSTER_SPRINGS_TOWN = "00364"
ADRIAN_CDP = "00460"
ALBRIGHT_TOWN = "00748"
ALDERSON_TOWN = "00772"
ALUM_CREEK_CDP = "01396"
AMHERSTDALE_CDP = "01660"
ANAWALT_TOWN = "01780"
ANMOORE_TOWN = "01900"
ANSTED_TOWN = "01996"
APPLE_GROVE_CDP = "02188"
ARBOVALE_CDP = "02260"
ARTHURDALE_CDP = "02908"
ATHENS_TOWN = "03292"
AUBURN_TOWN = "03364"
AURORA_CDP = "03460"
BANCROFT_TOWN = "04204"
BARBOURSVILLE_VILLAGE = "04276"
BARRACKVILLE_TOWN = "04612"
BARTLEY_CDP = "04732"
BARTOW_CDP = "04780"
BATH_BERKELEY_SPRINGS_TOWN = "04876"
BAXTER_CDP = "04900"
BAYARD_TOWN = "04924"
BEARDS_FORK_CDP = "05068"
BEAVER_CDP = "05260"
BECKLEY_CITY = "05332"
BEECH_BOTTOM_VILLAGE = "05452"
BELINGTON_TOWN = "05788"
BELLE_TOWN = "05836"
BELMONT_CITY = "06004"
BELVA_CDP = "06052"
BENWOOD_CITY = "06340"
BERGOO_CDP = "06436"
BERWIND_CDP = "06748"
BETHANY_TOWN = "06844"
BETHLEHEM_VILLAGE = "06940"
BEVERLY_TOWN = "06988"
BIG_CHIMNEY_CDP = "07204"
BIG_CREEK_CDP = "07228"
BIG_SANDY_CDP = "07516"
BIRCH_RIVER_CDP = "07756"
BLACKSVILLE_TOWN = "08092"
BLENNERHASSETT_CDP = "08308"
BLUEFIELD_CITY = "08524"
BLUEWELL_CDP = "08764"
BOAZ_CDP = "08836"
BOLIVAR_TOWN = "08932"
BOLT_CDP = "08956"
BOOMER_CDP = "09100"
BOOTH_CDP = "09148"
BOWDEN_CDP = "09364"
BRADLEY_CDP = "09676"
BRADSHAW_TOWN = "09700"
BRAMWELL_TOWN = "09796"
BRANDONVILLE_TOWN = "09844"
BRANDYWINE_CDP = "09868"
BRENTON_CDP = "09964"
BRIDGEPORT_CITY = "10180"
BROOKHAVEN_CDP = "10420"
BRUCETON_MILLS_TOWN = "10852"
BRUNO_CDP = "10876"
BRUSH_FORK_CDP = "10948"
BUCKHANNON_CITY = "11188"
BUD_CDP = "11212"
BUFFALO_TOWN = "11284"
BURLINGTON_CDP = "11620"
BURNSVILLE_TOWN = "11716"
CAIRO_TOWN = "12124"
CAMDEN_ON_GAULEY_TOWN = "12436"
CAMERON_CITY = "12484"
CAPON_BRIDGE_TOWN = "13108"
CAROLINA_CDP = "13468"
CARPENDALE_TOWN = "13525"
CASS_CDP = "13684"
CASSVILLE_CDP = "13756"
CEDAR_GROVE_TOWN = "13924"
CENTURY_CDP = "14212"
CEREDO_CITY = "14308"
CHAPMANVILLE_TOWN = "14524"
CHARLES_TOWN_CITY = "14610"
CHARLESTON_CITY = "14600"
CHARLTON_HEIGHTS_CDP = "14630"
CHATTAROY_CDP = "14692"
CHAUNCEY_CDP = "14716"
CHEAT_LAKE_CDP = "14775"
CHELYAN_CDP = "14812"
CHESAPEAKE_TOWN = "15028"
CHESTER_CITY = "15076"
CLARKSBURG_CITY = "15628"
CLAY_TOWN = "15676"
CLEARVIEW_VILLAGE = "15916"
CLENDENIN_TOWN = "16012"
CLIFTON_CDP = "16132"
COAL_CITY_CDP = "16516"
COAL_FORK_CDP = "16612"
COLCORD_CDP = "16972"
COLLIERS_CDP = "17140"
COMFORT_CDP = "17380"
CORINNE_CDP = "17836"
COTTAGEVILLE_CDP = "18124"
COVEL_CDP = "18388"
COWEN_TOWN = "18412"
CRAB_ORCHARD_CDP = "18508"
CRAIGSVILLE_CDP = "18604"
CROOKED_CREEK_CDP = "19060"
CROSS_LANES_CDP = "19108"
CRUM_CDP = "19300"
CRUMPLER_CDP = "19324"
CUCUMBER_CDP = "19492"
CULLODEN_CDP = "19516"
CUNARD_CDP = "19588"
DAILEY_CDP = "19948"
DANIELS_CDP = "20164"
DANVILLE_TOWN = "20212"
DAVIS_TOWN = "20428"
DAVY_TOWN = "20500"
DEEP_WATER_CDP = "20764"
DELBARTON_TOWN = "20980"
DESPARD_CDP = "21316"
DIXIE_CDP = "21628"
DOROTHY_CDP = "21964"
DUNBAR_CITY = "22564"
DUPONT_CITY_CDP = "22828"
DURBIN_TOWN = "22852"
EARLING_CDP = "23020"
EAST_BANK_TOWN = "23092"
EAST_DAILEY_CDP = "23140"
EAST_VIEW_CDP = "23524"
ECCLES_CDP = "23644"
ELEANOR_TOWN = "24292"
ELIZABETH_TOWN = "24364"
ELK_GARDEN_TOWN = "24484"
ELKINS_CITY = "24580"
ELKVIEW_CDP = "24748"
ELLENBORO_TOWN = "24844"
ENTERPRISE_CDP = "25516"
ESKDALE_CDP = "25732"
FAIRLEA_CDP = "26428"
FAIRMONT_CITY = "26452"
FAIRVIEW_TOWN = "26524"
FALLING_SPRING_TOWN = "26692"
FALLING_WATERS_CDP = "26716"
FALLS_VIEW_CDP = "26812"
FARMINGTON_TOWN = "26932"
FAYETTEVILLE_TOWN = "27028"
FENWICK_CDP = "27196"
FLATWOODS_TOWN = "27868"
FLEMINGTON_TOWN = "27940"
FOLLANSBEE_CITY = "28204"
FORT_ASHBY_CDP = "28444"
FORT_GAY_TOWN = "28516"
FRANK_CDP = "28948"
FRANKLIN_TOWN = "29044"
FRIENDLY_TOWN = "29404"
GALLIPOLIS_FERRY_CDP = "29716"
GALLOWAY_CDP = "29740"
GARTEN_CDP = "30148"
GARY_CITY = "30196"
GASSAWAY_TOWN = "30220"
GATEWOOD_CDP = "30316"
GAULEY_BRIDGE_TOWN = "30364"
GHENT_CDP = "30724"
GILBERT_CREEK_CDP = "30777"
GILBERT_TOWN = "30772"
GLASGOW_TOWN = "31324"
GLEN_DALE_CITY = "31492"
GLEN_FERRIS_CDP = "31732"
GLEN_FORK_CDP = "31756"
GLEN_JEAN_CDP = "31876"
GLEN_WHITE_CDP = "32068"
GLENVILLE_TOWN = "32044"
GRAFTON_CITY = "32716"
GRANT_TOWN_TOWN = "32908"
GRANTSVILLE_TOWN = "32884"
GRANVILLE_TOWN = "32932"
GREAT_CACAPON_CDP = "33100"
GREEN_BANK_CDP = "33124"
GREEN_SPRING_CDP = "33436"
GREENVIEW_CDP = "33580"
GREENVILLE_CDP = "33604"
GYPSY_CDP = "34180"
HAMBLETON_TOWN = "34492"
HAMLIN_TOWN = "34516"
HANDLEY_TOWN = "34756"
HANSFORD_CDP = "34852"
HARMAN_TOWN = "35092"
HARPERS_FERRY_TOWN = "35284"
HARRISVILLE_TOWN = "35428"
HARTFORD_CITY_TOWN = "35500"
HARTS_CDP = "35596"
HEDGESVILLE_TOWN = "36220"
HELEN_CDP = "36292"
HELVETIA_CDP = "36340"
HENDERSON_TOWN = "36436"
HENDRICKS_TOWN = "36460"
HENLAWSON_CDP = "36484"
HEPZIBAH_CDP = "36628"
HICO_CDP = "37036"
HILLSBORO_TOWN = "37372"
HILLTOP_CDP = "37444"
HINKLEVILLE_CDP = "37612"
HINTON_CITY = "37636"
HOLDEN_CDP = "37948"
HOLLYGROVE_CDP = "38092"
HOMETOWN_CDP = "38260"
HOOVERSON_HEIGHTS_CDP = "38476"
HUNDRED_TOWN = "39340"
HUNTERSVILLE_CDP = "39412"
HUNTINGTON_CITY = "39460"
HURRICANE_CITY = "39532"
HUTTONSVILLE_TOWN = "39628"
IAEGER_TOWN = "39652"
IDAMAY_CDP = "39676"
INSTITUTE_CDP = "40156"
INWOOD_CDP = "40204"
ITMANN_CDP = "40444"
JACKSONBURG_CDP = "40636"
JANE_LEW_TOWN = "40828"
JEFFERSON_CDP = "41010"
JUNIOR_TOWN = "42244"
JUSTICE_ADDITION_CDP = "42316"
JUSTICE_CDP = "42292"
KANAWHA_CDP = "42388"
KENOVA_CITY = "43180"
KERMIT_TOWN = "43300"
KEYSER_CITY = "43492"
KEYSTONE_CITY = "43516"
KIMBALL_TOWN = "43780"
KIMBERLY_CDP = "43828"
KINCAID_CDP = "43852"
KINGWOOD_CITY = "44044"
KISTLER_CDP = "44188"
KOPPERSTON_CDP = "44548"
LASHMEET_CDP = "45292"
LAVALETTE_CDP = "45580"
LEON_TOWN = "46300"
LESAGE_CDP = "46420"
LESTER_TOWN = "46468"
LEWISBURG_CITY = "46636"
LITTLETON_CDP = "47788"
LOGAN_CITY = "48148"
LOST_CREEK_TOWN = "48748"
LUBECK_CDP = "49156"
LUMBERPORT_TOWN = "49252"
MABSCOTT_TOWN = "49492"
MACARTHUR_CDP = "49564"
MADISON_CITY = "50524"
MALDEN_CDP = "50836"
MALLORY_CDP = "50860"
MAN_TOWN = "50932"
MANNINGTON_CITY = "51100"
MARLINTON_TOWN = "51676"
MARMET_CITY = "51724"
MARTINSBURG_CITY = "52060"
MASON_TOWN = "52180"
MASONTOWN_TOWN = "52228"
MATEWAN_TOWN = "52324"
MATHENY_CDP = "52372"
MATOAKA_TOWN = "52420"
MAYBEURY_CDP = "52588"
MCCONNELL_CDP = "49732"
MCMECHEN_CITY = "50260"
MEADOW_BRIDGE_TOWN = "52780"
MIDDLEBOURNE_TOWN = "53572"
MIDDLEWAY_CDP = "53692"
MILL_CREEK_TOWN = "54100"
MILTON_TOWN = "54484"
MINERALWELLS_CDP = "54580"
MITCHELL_HEIGHTS_TOWN = "54892"
MONAVILLE_CDP = "55132"
MONONGAH_TOWN = "55276"
MONTCALM_CDP = "55372"
MONTGOMERY_CITY = "55468"
MONTROSE_TOWN = "55540"
MOOREFIELD_TOWN = "55588"
MORGANTOWN_CITY = "55756"
MOUNDSVILLE_CITY = "56020"
MOUNT_CARBON_CDP = "56212"
MOUNT_GAY_SHAMROCK_CDP = "56342"
MOUNT_HOPE_CITY = "56404"
MULLENS_CITY = "57148"
NEIBERT_CDP = "57916"
NETTIE_CDP = "58180"
NEW_CUMBERLAND_CITY = "58372"
NEW_HAVEN_TOWN = "58564"
NEW_MARTINSVILLE_CITY = "58684"
NEW_RICHMOND_CDP = "58756"
NEWARK_CDP = "58252"
NEWBURG_TOWN = "58300"
NEWELL_CDP = "58420"
NITRO_CITY = "59068"
NORTH_HILLS_TOWN = "59458"
NORTHFORK_TOWN = "59428"
NORTON_CDP = "59668"
NUTTER_FORT_TOWN = "59836"
OAK_HILL_CITY = "60028"
OAKVALE_TOWN = "60196"
OCEANA_TOWN = "60364"
OMAR_CDP = "60628"
OSAGE_CDP = "61180"
PADEN_CITY_CITY = "61636"
PAGE_CDP = "61660"
PAGETON_CDP = "61684"
PARCOAL_CDP = "62044"
PARKERSBURG_CITY = "62140"
PARSONS_CITY = "62284"
PAW_PAW_TOWN = "62332"
PAX_TOWN = "62356"
PEA_RIDGE_CDP = "62488"
PEACH_CREEK_CDP = "62428"
PENNSBORO_CITY = "62764"
PENTRESS_CDP = "62788"
PETERSBURG_CITY = "62956"
PETERSTOWN_TOWN = "63052"
PHILIPPI_CITY = "63292"
PICKENS_CDP = "63484"
PIEDMONT_TOWN = "63604"
PINCH_CDP = "63772"
PINE_GROVE_TOWN = "63892"
PINEVILLE_TOWN = "63940"
PINEY_VIEW_CDP = "63988"
PLEASANT_VALLEY_CITY = "64228"
POCA_TOWN = "64516"
POINT_PLEASANT_CITY = "64708"
POWELLTON_CDP = "65284"
PRATT_TOWN = "65356"
PRICHARD_CDP = "65596"
PRINCE_CDP = "65668"
PRINCETON_CITY = "65692"
PROSPERITY_CDP = "65836"
PULLMAN_TOWN = "65956"
QUINWOOD_TOWN = "66412"
RACHEL_CDP = "66460"
RACINE_CDP = "66484"
RAINELLE_TOWN = "66652"
RALEIGH_CDP = "66748"
RAND_CDP = "66892"
RANSON_CORPORATION = "66988"
RAVENSWOOD_CITY = "67108"
RAYMOND_CITY_CDP = "67204"
RAYSAL_CDP = "67228"
READER_CDP = "67252"
RED_JACKET_CDP = "67396"
REEDSVILLE_TOWN = "67636"
REEDY_TOWN = "67660"
REYNOLDSVILLE_CDP = "67972"
RHODELL_TOWN = "67996"
RICHWOOD_CITY = "68116"
RIDGELEY_TOWN = "68260"
RIPLEY_CITY = "68596"
RIVESVILLE_TOWN = "68908"
ROBINETTE_CDP = "69100"
ROCK_CAVE_CDP = "69244"
RODERFIELD_CDP = "69844"
ROMNEY_CITY = "70084"
RONCEVERTE_CITY = "70156"
ROSSMORE_CDP = "70468"
ROWLESBURG_TOWN = "70588"
RUPERT_TOWN = "70828"
SALEM_CITY = "71380"
SALT_ROCK_CDP = "71476"
SAND_FORK_TOWN = "71620"
SARAH_ANN_CDP = "72004"
SCARBRO_CDP = "72292"
SHADY_SPRING_CDP = "73108"
SHANNONDALE_CDP = "73252"
SHENANDOAH_JUNCTION_CDP = "73444"
SHEPHERDSTOWN_TOWN = "73468"
SHINNSTON_CITY = "73636"
SHREWSBURY_CDP = "73876"
SISSONVILLE_CDP = "74356"
SISTERSVILLE_CITY = "74380"
SMITHERS_CITY = "74740"
SMITHFIELD_TOWN = "74788"
SOPHIA_TOWN = "75172"
SOUTH_CHARLESTON_CITY = "75292"
SPELTER_CDP = "75796"
SPENCER_CITY = "75820"
SPRAGUE_CDP = "75868"
SPRINGFIELD_CDP = "76084"
ST_ALBANS_CITY = "71212"
ST_GEORGE_CDP = "71284"
ST_MARYS_CITY = "71356"
STANAFORD_CDP = "76444"
STAR_CITY_TOWN = "76516"
STOLLINGS_CDP = "76996"
STONEWOOD_CITY = "77188"
SUMMERSVILLE_CITY = "77980"
SUTTON_TOWN = "78580"
SWITZER_CDP = "78796"
SYLVESTER_TOWN = "78964"
TEAYS_VALLEY_CDP = "79545"
TERRA_ALTA_TOWN = "79708"
THOMAS_CITY = "80020"
THURMOND_TOWN = "80284"
TIOGA_CDP = "80476"
TORNADO_CDP = "80764"
TRIADELPHIA_TOWN = "80932"
TUNNELTON_TOWN = "81268"
TWILIGHT_CDP = "81484"
UNION_TOWN = "81940"
VALLEY_BEND_CDP = "82564"
VALLEY_GROVE_VILLAGE = "82732"
VALLEY_HEAD_CDP = "82756"
VAN_CDP = "82852"
VERDUNVILLE_CDP = "83332"
VIENNA_CITY = "83500"
VIVIAN_CDP = "83764"
WALLACE_CDP = "84172"
WAR_CITY = "84484"
WARDENSVILLE_TOWN = "84580"
WASHINGTON_CDP = "84724"
WAVERLY_CDP = "84916"
WAYNE_TOWN = "84940"
WEIRTON_CITY = "85156"
WELCH_CITY = "85228"
WELLSBURG_CITY = "85324"
WEST_DUNBAR_CDP = "85636"
WEST_HAMLIN_TOWN = "85804"
WEST_LIBERTY_TOWN = "85876"
WEST_LOGAN_TOWN = "85900"
WEST_MILFORD_TOWN = "85924"
WEST_UNION_TOWN = "86116"
WESTON_CITY = "85972"
WESTOVER_CITY = "85996"
WHEELING_CITY = "86452"
WHITE_HALL_TOWN = "86620"
WHITE_SULPHUR_SPRINGS_CITY = "86812"
WHITESVILLE_TOWN = "86836"
WHITMER_CDP = "86932"
WILEY_FORD_CDP = "87316"
WILLIAMSON_CITY = "87508"
WILLIAMSTOWN_CITY = "87556"
WINDSOR_HEIGHTS_VILLAGE = "87892"
WINFIELD_TOWN = "87988"
WOLF_SUMMIT_CDP = "88276"
WOMELSDORF_COALTON_TOWN = "88324"
WORTHINGTON_TOWN = "88708"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Virginia."""


ABBS_VALLEY_CDP = "00110"
ABINGDON_TOWN = "00148"
ACCOMAC_TOWN = "00180"
ADWOLF_CDP = "00468"
AFTON_CDP = "00484"
ALBERTA_TOWN = "00724"
ALDIE_CDP = "00772"
ALEXANDRIA_CITY = "01000"
ALLISON_GAP_CDP = "01240"
ALLISONIA_CDP = "01256"
ALTAVISTA_TOWN = "01528"
AMELIA_COURT_HOUSE_CDP = "01640"
AMHERST_TOWN = "01672"
AMONATE_CDP = "01752"
ANNANDALE_CDP = "01912"
APPALACHIA_TOWN = "02040"
APPLE_MOUNTAIN_LAKE_CDP = "02064"
APPOMATTOX_TOWN = "02072"
AQUIA_HARBOUR_CDP = "02112"
ARCOLA_CDP = "02248"
ARLINGTON_CDP = "03000"
ARRINGTON_CDP = "03208"
ASHBURN_CDP = "03320"
ASHLAND_TOWN = "03368"
ATKINS_CDP = "03512"
ATLANTIC_CDP = "03528"
AUGUSTA_SPRINGS_CDP = "03608"
AUSTINVILLE_CDP = "03656"
BAILEYS_CROSSROADS_CDP = "04088"
BARBOURSVILLE_CDP = "04392"
BASKERVILLE_CDP = "04856"
BASSETT_CDP = "04872"
BASTIAN_CDP = "04904"
BASYE_CDP = "04920"
BAYSIDE_CDP = "05200"
BAYWOOD_CDP = "05256"
BEALETON_CDP = "05336"
BEDFORD_TOWN = "05544"
BELLE_HAVEN_CDP = "05928"
BELLE_HAVEN_TOWN = "05912"
BELLWOOD_CDP = "06216"
BELMONT_CDP = "06275"
BELMONT_ESTATES_CDP = "06336"
BELSPRING_CDP = "06424"
BELVIEW_CDP = "06512"
BENNS_CHURCH_CDP = "06712"
BENSLEY_CDP = "06728"
BERRYVILLE_TOWN = "06968"
BETHEL_MANOR_CDP = "07160"
BIG_ISLAND_CDP = "07400"
BIG_ROCK_CDP = "07448"
BIG_STONE_GAP_EAST_CDP = "07484"
BIG_STONE_GAP_TOWN = "07480"
BLACKSBURG_TOWN = "07784"
BLACKSTONE_TOWN = "07832"
BLAIRS_CDP = "07944"
BLAND_CDP = "07976"
BLOXOM_TOWN = "08120"
BLUE_RIDGE_CDP = "08200"
BLUE_RIDGE_SHORES_CDP = "08264"
BLUEFIELD_TOWN = "08152"
BOBTOWN_CDP = "08320"
BOISSEVAIN_CDP = "08376"
BON_AIR_CDP = "08472"
BOONES_MILL_TOWN = "08584"
BOSTON_CDP = "08675"
BOSWELLS_CORNER_CDP = "08708"
BOWLING_GREEN_TOWN = "08888"
BOYCE_TOWN = "08984"
BOYDTON_TOWN = "09016"
BOYKINS_TOWN = "09032"
BRACEY_CDP = "09064"
BRADDOCK_CDP = "09072"
BRAMBLETON_CDP = "09188"
BRANCHVILLE_TOWN = "09208"
BRANDERMILL_CDP = "09248"
BRANDY_STATION_CDP = "09352"
BREAKS_CDP = "09400"
BRIDGEWATER_TOWN = "09656"
BRIGHTWOOD_CDP = "09752"
BRISTOL_CITY = "09816"
BROADLANDS_CDP = "09952"
BROADWAY_TOWN = "10040"
BRODNAX_TOWN = "10072"
BROOKNEAL_TOWN = "10296"
BRUCETOWN_CDP = "10568"
BUCHANAN_TOWN = "10744"
BUCKHALL_CDP = "10776"
BUCKINGHAM_COURTHOUSE_CDP = "10856"
BUENA_VISTA_CITY = "11032"
BULL_RUN_CDP_FAIRFAX_COUNTY = "11224"
BULL_RUN_CDP_PRINCE_WILLIAM_COUNTY = "11230"
BULL_RUN_MOUNTAIN_ESTATES_CDP = "11245"
BURKE_CDP = "11464"
BURKE_CENTRE_CDP = "11470"
BURKEVILLE_TOWN = "11560"
CALLAGHAN_CDP = "12136"
CALVERTON_CDP = "12264"
CAMP_BARRETT_CDP = "12472"
CAMPTOWN_CDP = "12590"
CANA_CDP = "12600"
CAPE_CHARLES_TOWN = "12808"
CAPRON_TOWN = "12904"
CAPTAINS_COVE_CDP = "12915"
CARROLLTON_CDP = "13160"
CARRSVILLE_CDP = "13192"
CASCADES_CDP = "13403"
CASTLEWOOD_CDP = "13512"
CATLETT_CDP = "13624"
CATS_BRIDGE_CDP = "13635"
CAVE_SPRING_CDP = "13720"
CEDAR_BLUFF_TOWN = "13784"
CENTRAL_GARAGE_CDP = "14312"
CENTREVILLE_CDP = "14440"
CHAMBERLAYNE_CDP = "14544"
CHANTILLY_CDP = "14744"
CHARLES_CITY_CDP = "14904"
CHARLOTTE_COURT_HOUSE_TOWN = "14952"
CHARLOTTESVILLE_CITY = "14968"
CHASE_CITY_TOWN = "14984"
CHASE_CROSSING_CDP = "14995"
CHATHAM_TOWN = "15000"
CHATMOSS_CDP = "15048"
CHERITON_TOWN = "15112"
CHERRY_HILL_CDP = "15176"
CHESAPEAKE_CITY = "16000"
CHESTER_CDP = "16096"
CHESTER_GAP_CDP = "16240"
CHILHOWIE_TOWN = "16480"
CHINCOTEAGUE_TOWN = "16512"
CHRISTIANSBURG_TOWN = "16608"
CHURCHVILLE_CDP = "16736"
CLAREMONT_TOWN = "16880"
CLARKSVILLE_TOWN = "16992"
CLAYPOOL_HILL_CDP = "17120"
CLEVELAND_TOWN = "17296"
CLIFTON_FORGE_TOWN = "17440"
CLIFTON_TOWN = "17376"
CLIFTONDALE_PARK_CDP = "17424"
CLINCHCO_TOWN = "17504"
CLINCHPORT_TOWN = "17536"
CLINTWOOD_TOWN = "17552"
CLOVER_CDP = "17632"
CLOVERDALE_CDP = "17680"
CLUSTER_SPRINGS_CDP = "17776"
COEBURN_TOWN = "17952"
COLLINSVILLE_CDP = "18352"
COLONIAL_BEACH_TOWN = "18400"
COLONIAL_HEIGHTS_CITY = "18448"
COLUMBIA_CDP = "18624"
CONCORD_CDP = "18880"
COUNTRYSIDE_CDP = "19560"
COUNTY_CENTER_CDP = "19571"
COURTLAND_TOWN = "19600"
COVINGTON_CITY = "19728"
CRAIGSVILLE_TOWN = "19904"
CREWE_TOWN = "20160"
CRIMORA_CDP = "20240"
CROSSPOINTE_CDP = "20436"
CROZET_CDP = "20560"
CULPEPER_TOWN = "20752"
CUMBERLAND_CDP = "20768"
DAHLGREN_CDP = "21008"
DAHLGREN_CENTER_CDP = "21016"
DALE_CITY_CDP = "21088"
DALEVILLE_CDP = "21152"
DAMASCUS_TOWN = "21184"
DANTE_CDP = "21312"
DANVILLE_CITY = "21344"
DAYTON_TOWN = "21648"
DEEP_CREEK_CDP = "21776"
DEERFIELD_CDP = "21872"
DELTAVILLE_CDP = "22064"
DENDRON_TOWN = "22160"
DIFFICULT_RUN_CDP = "22472"
DILLWYN_TOWN = "22560"
DINWIDDIE_CDP = "22576"
DISPUTANTA_CDP = "22640"
DOOMS_CDP = "22976"
DORAN_CDP = "23008"
DRAKES_BRANCH_TOWN = "23376"
DRANESVILLE_CDP = "23392"
DRAPER_CDP = "23408"
DRYDEN_CDP = "23584"
DUBLIN_TOWN = "23648"
DUFFIELD_TOWN = "23680"
DULLES_TOWN_CENTER_CDP = "23732"
DUMBARTON_CDP = "23744"
DUMFRIES_TOWN = "23760"
DUNBAR_CDP = "23776"
DUNGANNON_TOWN = "23952"
DUNN_LORING_CDP = "23984"
EAGLE_ROCK_CDP = "24208"
EARLYSVILLE_CDP = "24272"
EAST_HIGHLAND_PARK_CDP = "24496"
EAST_LEXINGTON_CDP = "24544"
EAST_STONE_GAP_CDP = "24720"
EASTVILLE_TOWN = "24752"
EBONY_CDP = "24816"
EDINBURG_TOWN = "25008"
EGGLESTON_CDP = "25136"
ELKTON_TOWN = "25408"
ELLISTON_CDP = "25488"
EMORY_CDP = "25792"
EMPORIA_CITY = "25808"
ENON_CDP = "25877"
ESMONT_CDP = "25968"
ETTRICK_CDP = "26128"
EWING_CDP = "26384"
EXMORE_TOWN = "26416"
FAIR_LAKES_CDP = "26701"
FAIR_OAKS_CDP = "26875"
FAIRFAX_STATION_CDP = "26592"
FAIRFAX_CITY = "26496"
FAIRFIELD_CDP = "26656"
FAIRLAWN_CDP = "26736"
FAIRVIEW_BEACH_CDP = "27040"
FAIRVIEW_CDP = "26944"
FALLS_CHURCH_CITY = "27200"
FALLS_MILLS_CDP = "27232"
FALMOUTH_CDP = "27264"
FANCY_GAP_CDP = "27296"
FARMVILLE_TOWN = "27440"
FERRUM_CDP = "27712"
FIELDALE_CDP = "27744"
FINCASTLE_TOWN = "27824"
FISHERSVILLE_CDP = "27968"
FLINT_HILL_CDP = "28496"
FLORIS_CDP = "28528"
FLOYD_TOWN = "28544"
FOREST_CDP = "28688"
FORT_BELVOIR_CDP = "29008"
FORT_CHISWELL_CDP = "29040"
FORT_HUNT_CDP = "29136"
FORT_LEE_CDP = "29152"
FRANCONIA_CDP = "29552"
FRANKLIN_FARM_CDP = "29628"
FRANKLIN_CITY = "29600"
FRANKTOWN_CDP = "29712"
FREDERICKSBURG_CITY = "29744"
FREE_UNION_CDP = "29840"
FRIES_TOWN = "29920"
FRONT_ROYAL_TOWN = "29968"
GAINESVILLE_CDP = "30176"
GALAX_CITY = "30208"
GARGATHA_CDP = "30384"
GASBURG_CDP = "30480"
GATE_CITY_TOWN = "30496"
GEORGE_MASON_CDP = "30618"
GLADE_SPRING_TOWN = "31056"
GLASGOW_TOWN = "31136"
GLEN_ALLEN_CDP = "31200"
GLEN_LYN_TOWN = "31376"
GLEN_WILTON_CDP = "31504"
GLENVAR_CDP = "31488"
GLOUCESTER_COURTHOUSE_CDP = "31608"
GLOUCESTER_POINT_CDP = "31616"
GOOCHLAND_CDP = "31808"
GOOSE_CREEK_VILLAGE_CDP = "31912"
GORDONSVILLE_TOWN = "31936"
GORE_CDP = "31952"
GOSHEN_TOWN = "31968"
GRATTON_CDP = "32320"
GREAT_FALLS_CDP = "32496"
GREAT_FALLS_CROSSING_CDP = "32498"
GREENBACKVILLE_CDP = "32560"
GREENBRIAR_CDP = "32592"
GREENBUSH_CDP = "32624"
GREENVILLE_CDP = "32944"
GRETNA_TOWN = "33232"
GROTTOES_TOWN = "33488"
GROVETON_CDP = "33584"
GRUNDY_TOWN = "33648"
GWYNN_CDP = "33824"
HALIFAX_TOWN = "34064"
HALLWOOD_TOWN = "34176"
HAMILTON_TOWN = "34240"
HAMPDEN_SYDNEY_CDP = "34304"
HAMPTON_CITY = "35000"
HANOVER_CDP = "35160"
HARBORTON_CDP = "35240"
HARRISONBURG_CITY = "35624"
HARRISTON_CDP = "35640"
HAYFIELD_CDP = "35912"
HAYMARKET_TOWN = "35976"
HAYSI_TOWN = "36008"
HEATHSVILLE_CDP = "36216"
HENRY_FORK_CDP = "36445"
HERNDON_TOWN = "36648"
HIGHLAND_SPRINGS_CDP = "37032"
HILLSBORO_TOWN = "37288"
HILLSVILLE_TOWN = "37336"
HILLTOWN_CDP = "37380"
HILTONS_CDP = "37432"
HIWASSEE_CDP = "37544"
HOLLINS_CDP = "37880"
HOLLYMEAD_CDP = "38032"
HONAKER_TOWN = "38280"
HOPEWELL_CITY = "38424"
HORNTOWN_CDP = "38504"
HORSE_PASTURE_CDP = "38552"
HOT_SPRINGS_CDP = "38632"
HUNTINGTON_CDP = "39064"
HURT_TOWN = "39224"
HUTCHISON_CDP = "39259"
HYBLA_VALLEY_CDP = "39304"
IDYLWOOD_CDP = "39448"
INDEPENDENCE_TOWN = "39528"
INDEPENDENT_HILL_CDP = "39544"
INNOVATION_CDP = "39916"
INNSBROOK_CDP = "39920"
IRON_GATE_TOWN = "40024"
IRVINGTON_TOWN = "40088"
IVANHOE_CDP = "40216"
IVOR_TOWN = "40232"
IVY_CDP = "40248"
JARRATT_TOWN = "40536"
JEWELL_RIDGE_CDP = "41016"
JOLIVUE_CDP = "41144"
JONESVILLE_TOWN = "41272"
KEEZLETOWN_CDP = "41624"
KELLER_TOWN = "41656"
KENBRIDGE_TOWN = "41832"
KEOKEE_CDP = "42104"
KESWICK_CDP = "42216"
KEYSVILLE_TOWN = "42264"
KILMARNOCK_TOWN = "42424"
KINCORA_CDP = "42501"
KING_GEORGE_CDP = "42568"
KING_WILLIAM_CDP = "42792"
KING_AND_QUEEN_COURT_HOUSE_CDP = "42536"
KINGS_PARK_CDP = "42664"
KINGS_PARK_WEST_CDP = "42680"
KINGSTOWNE_CDP = "42746"
LA_CROSSE_TOWN = "43176"
LAFAYETTE_CDP = "43224"
LAKE_BARCROFT_CDP = "43352"
LAKE_CAROLINE_CDP = "43359"
LAKE_HOLIDAY_CDP = "43392"
LAKE_LANDOR_CDP = "43420"
LAKE_MONTICELLO_CDP = "43424"
LAKE_RIDGE_CDP = "43432"
LAKE_WILDERNESS_CDP = "43600"
LAKE_OF_THE_WOODS_CDP = "43430"
LAKESIDE_CDP = "43464"
LANCASTER_CDP = "43704"
LANSDOWNE_CDP = "44048"
LAUREL_CDP = "44280"
LAUREL_HILL_CDP = "44430"
LAUREL_PARK_CDP = "44476"
LAWRENCEVILLE_TOWN = "44520"
LAYMANTOWN_CDP = "44620"
LEBANON_TOWN = "44696"
LEE_MONT_CDP = "44952"
LEESBURG_TOWN = "44984"
LEESYLVANIA_CDP = "45008"
LEXINGTON_CITY = "45512"
LINCOLNIA_CDP = "45784"
LINTON_HALL_CDP = "45957"
LINVILLE_CDP = "45960"
LOCH_LOMOND_CDP = "46328"
LOCUST_MOUNT_CDP = "46456"
LONG_BRANCH_CDP = "46760"
LORTON_CDP = "47064"
LOUDOUN_VALLEY_ESTATES_CDP = "47136"
LOUISA_TOWN = "47144"
LOVETTSVILLE_TOWN = "47208"
LOVINGSTON_CDP = "47224"
LOW_MOOR_CDP = "47352"
LOWES_ISLAND_CDP = "47296"
LUNENBURG_CDP = "47496"
LURAY_TOWN = "47528"
LYNCHBURG_CITY = "47672"
LYNDHURST_CDP = "47720"
MADISON_HEIGHTS_CDP = "48520"
MADISON_TOWN = "48488"
MAKEMIE_PARK_CDP = "48776"
MALLOW_CDP = "48856"
MANASSAS_PARK_CITY = "48968"
MANASSAS_CITY = "48952"
MANCHESTER_CDP = "48996"
MANTUA_CDP = "49144"
MAPPSBURG_CDP = "49320"
MAPPSVILLE_CDP = "49336"
MARION_TOWN = "49464"
MARSHALL_CDP = "49656"
MARTINSVILLE_CITY = "49784"
MASON_NECK_CDP = "49998"
MASSANETTA_SPRINGS_CDP = "50020"
MASSANUTTEN_CDP = "50030"
MATHEWS_CDP = "50104"
MATOACA_CDP = "50136"
MAURERTOWN_CDP = "50200"
MAX_MEADOWS_CDP = "50312"
MCDOWELL_CDP = "48184"
MCGAHEYSVILLE_CDP = "48232"
MCKENNEY_TOWN = "48344"
MCLEAN_CDP = "48376"
MCMULLIN_CDP = "48445"
MCNAIR_CDP = "48450"
MEADOWBROOK_CDP = "50568"
MEADOWS_OF_DAN_CDP = "50696"
MEADOWVIEW_CDP = "50760"
MECHANICSBURG_CDP = "50840"
MECHANICSVILLE_CDP = "50856"
MELFA_TOWN = "50984"
MENDOTA_CDP = "51096"
MERRIFIELD_CDP = "51192"
MERRIMAC_CDP = "51208"
METOMPKIN_CDP = "51362"
MIDDLEBROOK_CDP = "51432"
MIDDLEBURG_TOWN = "51448"
MIDDLETOWN_TOWN = "51512"
MIDLAND_CDP = "51544"
MIDLOTHIAN_CDP = "51560"
MILLBORO_CDP = "51848"
MINERAL_TOWN = "52120"
MODEST_TOWN_CDP = "52408"
MONETA_CDP = "52536"
MONTCLAIR_CDP = "52658"
MONTEREY_TOWN = "52680"
MONTROSE_CDP = "52904"
MONTROSS_TOWN = "52952"
MONTVALE_CDP = "52968"
MOOREFIELD_CDP = "53030"
MOTLEY_CDP = "53480"
MOUNT_CLIFTON_CDP = "53832"
MOUNT_CRAWFORD_TOWN = "53864"
MOUNT_HERMON_CDP = "53944"
MOUNT_JACKSON_TOWN = "53992"
MOUNT_SIDNEY_CDP = "54120"
MOUNT_VERNON_CDP = "54144"
MOUNTAIN_ROAD_CDP = "53584"
NARROWS_TOWN = "54904"
NASSAWADOX_TOWN = "54984"
NATHALIE_CDP = "55000"
NAVY_CDP = "55208"
NELLYSFORD_CDP = "55400"
NELSONIA_CDP = "55448"
NEW_BALTIMORE_CDP = "55528"
NEW_CASTLE_TOWN = "55592"
NEW_CHURCH_CDP = "55608"
NEW_HOPE_CDP = "55720"
NEW_KENT_CDP = "55800"
NEW_MARKET_TOWN = "55848"
NEW_RIVER_CDP = "56048"
NEWINGTON_CDP = "55752"
NEWINGTON_FOREST_CDP = "55758"
NEWPORT_NEWS_CITY = "56000"
NEWSOMS_TOWN = "56096"
NICKELSVILLE_TOWN = "56304"
NOKESVILLE_CDP = "56464"
NORFOLK_CITY = "57000"
NORTH_GARDEN_CDP = "57368"
NORTH_SHORE_CDP = "57531"
NORTH_SPRINGFIELD_CDP = "57560"
NORTON_CITY = "57688"
NOTTOWAY_COURT_HOUSE_CDP = "57870"
OAK_GROVE_CDP = "58104"
OAK_HALL_CDP = "58184"
OAK_LEVEL_CDP = "58312"
OAKTON_CDP = "58472"
OCCOQUAN_TOWN = "58696"
ONANCOCK_TOWN = "59336"
ONE_LOUDOUN_CDP = "59364"
ONLEY_TOWN = "59384"
OPAL_CDP = "59416"
ORANGE_TOWN = "59496"
OSAKA_CDP = "59752"
PAINTER_TOWN = "60296"
PALMYRA_CDP = "60392"
PAMPLIN_CITY_TOWN = "60488"
PANTOPS_CDP = "60512"
PARIS_CDP = "60536"
PARKSLEY_TOWN = "60680"
PARROTT_CDP = "60840"
PASSAPATANZY_CDP = "60888"
PASTORIA_CDP = "60920"
PATRICK_SPRINGS_CDP = "60984"
PEARISBURG_TOWN = "61208"
PEMBROKE_TOWN = "61336"
PENHOOK_CDP = "61464"
PENNINGTON_GAP_TOWN = "61560"
PETERSBURG_CITY = "61832"
PHENIX_TOWN = "61896"
PIMMIT_HILLS_CDP = "62264"
PINEY_MOUNTAIN_CDP = "62738"
PLUM_CREEK_CDP = "63190"
POCAHONTAS_TOWN = "63288"
POQUOSON_CITY = "63768"
PORT_REPUBLIC_CDP = "63896"
PORT_ROYAL_TOWN = "63928"
PORTSMOUTH_CITY = "64000"
POTOMAC_MILLS_CDP = "64152"
POUND_TOWN = "64272"
POUNDING_MILL_CDP = "64288"
POWHATAN_CDP = "64384"
PRICES_FORK_CDP = "64512"
PRINCE_GEORGE_CDP = "64560"
PULASKI_TOWN = "64880"
PUNGOTEAGUE_CDP = "64976"
PURCELLVILLE_TOWN = "65008"
QUANTICO_BASE_CDP = "65128"
QUANTICO_TOWN = "65120"
QUINBY_CDP = "65280"
RADFORD_CITY = "65392"
RAVEN_CDP = "65744"
RAVENSWORTH_CDP = "65776"
RECTORTOWN_CDP = "66032"
REMINGTON_TOWN = "66512"
RESTON_CDP = "66672"
RICH_CREEK_TOWN = "66896"
RICHLANDS_TOWN = "66928"
RICHMOND_CITY = "67000"
RIDGEWAY_TOWN = "67208"
RINER_CDP = "67256"
RIO_CDP = "67288"
RIPPLEMEAD_CDP = "67304"
RIVANNA_CDP = "67331"
RIVERDALE_CDP = "67352"
RIVERVIEW_CDP = "67704"
ROANOKE_CITY = "68000"
ROCKWOOD_CDP = "68470"
ROCKY_GAP_CDP = "68480"
ROCKY_MOUNT_TOWN = "68496"
ROSE_HILL_CDP_FAIRFAX_COUNTY = "68880"
ROSE_HILL_CDP_LEE_COUNTY = "68885"
ROUND_HILL_TOWN = "69168"
RUCKERSVILLE_CDP = "69360"
RURAL_RETREAT_TOWN = "69456"
RUSHMERE_CDP = "69472"
RUSTBURG_CDP = "69536"
SALEM_CITY = "70000"
SALTVILLE_TOWN = "70096"
SALUDA_CDP = "70112"
SANDSTON_CDP = "70256"
SANDY_LEVEL_CDP = "70296"
SANFORD_CDP = "70352"
SAVAGE_TOWN_CDP = "70520"
SAVAGEVILLE_CDP = "70528"
SAXIS_TOWN = "70576"
SCHOONER_BAY_CDP = "70680"
SCHUYLER_CDP = "70704"
SCOTLAND_CDP = "70715"
SCOTTSBURG_TOWN = "70752"
SCOTTSVILLE_TOWN = "70800"
SEDLEY_CDP = "71040"
SELMA_CDP = "71072"
SEVEN_CORNERS_CDP = "71216"
SEVEN_MILE_FORD_CDP = "71264"
SHAWNEELAND_CDP = "71625"
SHAWSVILLE_CDP = "71632"
SHENANDOAH_FARMS_CDP = "71810"
SHENANDOAH_RETREAT_CDP = "71825"
SHENANDOAH_SHORES_CDP = "71826"
SHENANDOAH_TOWN = "71776"
SHERANDO_CDP = "71904"
SHIPMAN_CDP = "72080"
SHORT_PUMP_CDP = "72272"
SINGERS_GLEN_CDP = "72736"
SKYLAND_ESTATES_CDP = "72935"
SMITHFIELD_TOWN = "73200"
SNOWVILLE_CDP = "73376"
SOUTH_BOSTON_TOWN = "73712"
SOUTH_HILL_TOWN = "73904"
SOUTH_RIDING_CDP = "74100"
SOUTH_RUN_CDP = "74120"
SOUTHAMPTON_MEADOWS_CDP = "73624"
SOUTHERN_GATEWAY_CDP = "73760"
SOUTHSIDE_CHESCONESSEX_CDP = "74160"
SPERRYVILLE_CDP = "74384"
SPOTSYLVANIA_COURTHOUSE_CDP = "74470"
SPRINGFIELD_CDP = "74592"
SPRINGVILLE_CDP = "74848"
ST_CHARLES_TOWN = "69792"
ST_PAUL_TOWN = "69936"
STAFFORD_COURTHOUSE_CDP = "74916"
STANARDSVILLE_TOWN = "75008"
STANLEY_TOWN = "75024"
STANLEYTOWN_CDP = "75040"
STAUNTON_CITY = "75216"
STEPHENS_CITY_TOWN = "75344"
STERLING_CDP = "75376"
STEVENS_CREEK_CDP = "75440"
STEWARTSVILLE_CDP = "75504"
STICKLEYVILLE_CDP = "75536"
STONE_RIDGE_CDP = "75702"
STONEGA_CDP = "75680"
STONY_CREEK_TOWN = "75840"
STRASBURG_TOWN = "76000"
STUART_TOWN = "76256"
STUARTS_DRAFT_CDP = "76272"
SUDLEY_CDP = "76416"
SUFFOLK_CITY = "76432"
SUGAR_GROVE_CDP = "76448"
SUGARLAND_RUN_CDP = "76464"
SULLY_SQUARE_CDP = "76516"
SURRY_TOWN = "76880"
SUSSEX_CDP = "76912"
TACOMA_CDP = "77408"
TANGIER_TOWN = "77520"
TAPPAHANNOCK_TOWN = "77568"
TASLEY_CDP = "77648"
TAZEWELL_TOWN = "77792"
TEMPERANCEVILLE_CDP = "77856"
TEMPLETON_CDP = "77925"
THE_PLAINS_TOWN = "78192"
THE_UNIVERSITY_OF_VIRGINIAS_COLLEGE_AT_WISE_CDP = "78264"
THYNEDALE_CDP = "78532"
TIMBERLAKE_CDP = "78688"
TIMBERVILLE_TOWN = "78736"
TOMS_BROOK_TOWN = "79024"
TRIANGLE_CDP = "79360"
TROUTDALE_TOWN = "79456"
TROUTVILLE_TOWN = "79472"
TUCKAHOE_CDP = "79560"
TWIN_LAKES_CDP = "79768"
TYSONS_CDP = "79950"
UNION_HALL_CDP = "80000"
UNION_LEVEL_CDP = "80016"
UNION_MILL_CDP = "80029"
UNIVERSITY_CENTER_CDP = "80120"
UNIVERSITY_OF_VIRGINIA_CDP = "80165"
UPPERVILLE_CDP = "80224"
URBANNA_TOWN = "80272"
VANSANT_CDP = "80608"
VERONA_CDP = "80864"
VICTORIA_TOWN = "81024"
VIENNA_TOWN = "81072"
VILLA_HEIGHTS_CDP = "81152"
VINTON_TOWN = "81280"
VIRGILINA_TOWN = "81312"
VIRGINIA_BEACH_CITY = "82000"
WACHAPREAGUE_TOWN = "82320"
WAKEFIELD_CDP = "82371"
WAKEFIELD_TOWN = "82384"
WARFIELD_CDP = "83056"
WARM_SPRINGS_CDP = "83088"
WARRENTON_TOWN = "83136"
WARSAW_TOWN = "83168"
WASHINGTON_TOWN = "83248"
WATERFORD_CDP = "83440"
WATTSVILLE_CDP = "83568"
WAVERLY_TOWN = "83600"
WAYNESBORO_CITY = "83680"
WEBER_CITY_TOWN = "83808"
WEEMS_CDP = "83888"
WEST_FALLS_CHURCH_CDP = "84368"
WEST_POINT_TOWN = "84960"
WEST_SPRINGFIELD_CDP = "84976"
WESTLAKE_CORNER_CDP = "84632"
WEYERS_CAVE_CDP = "85184"
WHITE_STONE_TOWN = "85600"
WHITESVILLE_CDP = "85608"
WILLIAMSBURG_CITY = "86160"
WILLIS_WHARF_CDP = "86336"
WINCHESTER_CITY = "86720"
WINDSOR_TOWN = "86784"
WINTERGREEN_CDP = "87008"
WISE_TOWN = "87072"
WOLF_TRAP_CDP = "87240"
WOODBRIDGE_CDP = "87312"
WOODBURN_CDP = "87333"
WOODLAKE_CDP = "87380"
WOODLAWN_CDP_CARROLL_COUNTY = "87408"
WOODLAWN_CDP_FAIRFAX_COUNTY = "87410"
WOODSTOCK_TOWN = "87712"
WYNDHAM_CDP = "87960"
WYTHEVILLE_TOWN = "88000"
YOGAVILLE_CDP = "88145"
YORKSHIRE_CDP = "88176"
YORKTOWN_CDP = "88240"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in South Carolina."""


ABBEVILLE = "001"
AIKEN = "003"
ALLENDALE = "005"
ANDERSON = "007"
BAMBERG = "009"
BARNWELL = "011"
BEAUFORT = "013"
BERKELEY = "015"
CALHOUN = "017"
CHARLESTON = "019"
CHEROKEE = "021"
CHESTER = "023"
CHESTERFIELD = "025"
CLARENDON = "027"
COLLETON = "029"
DARLINGTON = "031"
DILLON = "033"
DORCHESTER = "035"
EDGEFIELD = "037"
FAIRFIELD = "039"
FLORENCE = "041"
GEORGETOWN = "043"
GREENVILLE = "045"
GREENWOOD = "047"
HAMPTON = "049"
HORRY = "051"
JASPER = "053"
KERSHAW = "055"
LANCASTER = "057"
LAURENS = "059"
LEE = "061"
LEXINGTON = "063"
MARION = "067"
MARLBORO = "069"
MCCORMICK = "065"
NEWBERRY = "071"
OCONEE = "073"
ORANGEBURG = "075"
PICKENS = "077"
RICHLAND = "079"
SALUDA = "081"
SPARTANBURG = "083"
SUMTER = "085"
UNION = "087"
WILLIAMSBURG = "089"
YORK = "091"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Wisconsin."""


ABBOTSFORD_CITY = "00100"
ABRAMS_CDP = "00150"
ADAMS_CITY = "00275"
ADELL_VILLAGE = "00450"
ALBANY_VILLAGE = "00750"
ALGOMA_CITY = "01000"
ALLENS_GROVE_CDP = "01075"
ALLENTON_CDP = "01100"
ALLOUEZ_VILLAGE = "01150"
ALMA_CENTER_VILLAGE = "01300"
ALMA_CITY = "01225"
ALMENA_VILLAGE = "01325"
ALMOND_VILLAGE = "01400"
ALTO_CDP = "01500"
ALTOONA_CITY = "01550"
AMBERG_CDP = "01650"
AMERY_CITY = "01725"
AMHERST_JUNCTION_VILLAGE = "01800"
AMHERST_VILLAGE = "01750"
ANGELICA_CDP = "01950"
ANIWA_VILLAGE = "02075"
ANTIGO_CITY = "02250"
APPLETON_CITY = "02375"
ARCADIA_CITY = "02500"
ARENA_VILLAGE = "02550"
ARGONNE_CDP = "02600"
ARGYLE_VILLAGE = "02650"
ARKANSAW_CDP = "02700"
ARKDALE_CDP = "02725"
ARLINGTON_VILLAGE = "02800"
ARPIN_VILLAGE = "03025"
ASHIPPUN_CDP = "03175"
ASHLAND_CITY = "03225"
ASHWAUBENON_VILLAGE = "03425"
ATHENS_VILLAGE = "03550"
AUBURNDALE_VILLAGE = "03775"
AUGUSTA_CITY = "03825"
AVOCA_VILLAGE = "04025"
BABCOCK_CDP = "04150"
BAGLEY_VILLAGE = "04250"
BAILEYS_HARBOR_CDP = "04300"
BALDWIN_VILLAGE = "04400"
BALSAM_LAKE_VILLAGE = "04475"
BANCROFT_CDP = "04525"
BANGOR_VILLAGE = "04550"
BARABOO_CITY = "04625"
BARNEVELD_VILLAGE = "04775"
BARRON_CITY = "04875"
BARRONETT_CDP = "04925"
BATAVIA_CDP = "05275"
BAY_CITY_VILLAGE = "05325"
BAYFIELD_CITY = "05350"
BAYFRONT_CDP = "05387"
BAYSIDE_VILLAGE = "05450"
BEAR_CREEK_VILLAGE = "05575"
BEAVER_DAM_CITY = "05900"
BELGIUM_VILLAGE = "06150"
BELL_CENTER_VILLAGE = "06225"
BELLEVILLE_VILLAGE = "06300"
BELLEVUE_VILLAGE = "06350"
BELMONT_VILLAGE = "06425"
BELOIT_CITY = "06500"
BENTON_VILLAGE = "06825"
BERLIN_CITY = "06925"
BIG_BEND_VILLAGE = "07200"
BIG_FALLS_VILLAGE = "07250"
BIG_FOOT_PRAIRIE_CDP = "07315"
BIRCH_HILL_CDP = "07532"
BIRCHWOOD_VILLAGE = "07550"
BIRNAMWOOD_VILLAGE = "07600"
BIRON_VILLAGE = "07650"
BLACK_CREEK_VILLAGE = "07725"
BLACK_EARTH_VILLAGE = "07800"
BLACK_RIVER_FALLS_CITY = "07900"
BLAIR_CITY = "08075"
BLANCHARDVILLE_VILLAGE = "08125"
BLOOMER_CITY = "08225"
BLOOMFIELD_VILLAGE = "08265"
BLOOMINGTON_VILLAGE = "08375"
BLUE_MOUNDS_VILLAGE = "08475"
BLUE_RIVER_VILLAGE = "08525"
BLUFFVIEW_CDP = "08560"
BOAZ_VILLAGE = "08600"
BOHNERS_LAKE_CDP = "08625"
BONDUEL_VILLAGE = "08725"
BOSCOBEL_CITY = "08850"
BOULDER_JUNCTION_CDP = "08925"
BOWLER_VILLAGE = "09025"
BOYCEVILLE_VILLAGE = "09050"
BOYD_VILLAGE = "09075"
BRANDON_VILLAGE = "09300"
BRICE_PRAIRIE_CDP = "09465"
BRIGGSVILLE_CDP = "09575"
BRILLION_CITY = "09725"
BRISTOL_VILLAGE = "09800"
BRODHEAD_CITY = "09925"
BROOKFIELD_CITY = "10025"
BROOKLYN_VILLAGE = "10075"
BROTHERTOWN_CDP = "10325"
BROWN_DEER_VILLAGE = "10375"
BROWNS_LAKE_CDP = "10425"
BROWNSVILLE_VILLAGE = "10450"
BROWNTOWN_VILLAGE = "10475"
BRUCE_VILLAGE = "10500"
BRULE_CDP = "10550"
BUFFALO_CITY_CITY = "11062"
BURLINGTON_CITY = "11200"
BURNETT_CDP = "11250"
BUTLER_VILLAGE = "11475"
BUTTE_DES_MORTS_CDP = "11500"
BUTTERNUT_VILLAGE = "11525"
CABLE_CDP = "11650"
CADOTT_VILLAGE = "11750"
CALEDONIA_VILLAGE = "11950"
CAMBRIA_VILLAGE = "12200"
CAMBRIDGE_VILLAGE = "12225"
CAMERON_VILLAGE = "12250"
CAMP_DOUGLAS_VILLAGE = "12350"
CAMPBELLSPORT_VILLAGE = "12325"
CAROLINE_CDP = "12675"
CASCADE_VILLAGE = "12825"
CASCO_VILLAGE = "12850"
CASHTON_VILLAGE = "12950"
CASSVILLE_VILLAGE = "13050"
CATARACT_CDP = "13150"
CATAWBA_VILLAGE = "13175"
CAZENOVIA_VILLAGE = "13300"
CECIL_VILLAGE = "13325"
CEDAR_GROVE_VILLAGE = "13475"
CEDARBURG_CITY = "13375"
CEEX_HACI_CDP = "13587"
CENTURIA_VILLAGE = "13850"
CHAIN_O_LAKES_CDP = "13880"
CHASEBURG_VILLAGE = "14150"
CHELSEA_CDP = "14175"
CHENEQUA_VILLAGE = "14225"
CHETEK_CITY = "14325"
CHIEF_LAKE_CDP = "14440"
CHILI_CDP = "14450"
CHILTON_CITY = "14475"
CHIPPEWA_FALLS_CITY = "14575"
CLAM_LAKE_CDP = "14850"
CLARKS_MILLS_CDP = "14925"
CLAYTON_VILLAGE = "15100"
CLEAR_LAKE_VILLAGE = "15250"
CLEVELAND_VILLAGE = "15400"
CLINTON_VILLAGE = "15625"
CLINTONVILLE_CITY = "15725"
CLYMAN_VILLAGE = "15900"
COBB_VILLAGE = "15975"
COCHRANE_VILLAGE = "16025"
COLBY_CITY = "16150"
COLEMAN_VILLAGE = "16250"
COLFAX_VILLAGE = "16275"
COLLINS_CDP = "16350"
COLOMA_VILLAGE = "16375"
COLUMBUS_CITY = "16450"
COMBINED_LOCKS_VILLAGE = "16500"
COMO_CDP = "16575"
CONRATH_VILLAGE = "16775"
COON_VALLEY_VILLAGE = "16900"
CORNELL_CITY = "17100"
CORNUCOPIA_CDP = "17150"
COTTAGE_GROVE_VILLAGE = "17175"
COUDERAY_VILLAGE = "17225"
CRANDON_CITY = "17425"
CRIVITZ_VILLAGE = "17725"
CROSS_PLAINS_VILLAGE = "17775"
CUBA_CITY_CITY = "17950"
CUDAHY_CITY = "17975"
CUMBERLAND_CITY = "18025"
CURTISS_VILLAGE = "18125"
DALE_CDP = "18500"
DALLAS_VILLAGE = "18575"
DALTON_CDP = "18625"
DANBURY_CDP = "18650"
DANE_VILLAGE = "18700"
DARIEN_VILLAGE = "18825"
DARLINGTON_CITY = "18875"
DE_PERE_CITY = "19775"
DE_SOTO_VILLAGE = "19850"
DEFOREST_VILLAGE = "19350"
DEER_PARK_VILLAGE = "19325"
DEERFIELD_VILLAGE = "19250"
DEKORRA_CDP = "19365"
DELAFIELD_CITY = "19400"
DELAVAN_LAKE_CDP = "19500"
DELAVAN_CITY = "19450"
DELLWOOD_CDP = "19600"
DENMARK_VILLAGE = "19700"
DIAMOND_BLUFF_CDP = "20125"
DIAPERVILLE_CDP = "20167"
DICKEYVILLE_VILLAGE = "20175"
DODGE_CDP = "20275"
DODGEVILLE_CITY = "20350"
DORCHESTER_VILLAGE = "20450"
DOUSMAN_VILLAGE = "20550"
DOWNING_VILLAGE = "20675"
DOWNSVILLE_CDP = "20725"
DOYLESTOWN_VILLAGE = "20775"
DRESSER_VILLAGE = "20850"
DRUMMOND_CDP = "20875"
DUNBAR_CDP = "20975"
DURAND_CITY = "21225"
DYCKESVILLE_CDP = "21375"
EAGLE_LAKE_CDP = "21525"
EAGLE_RIVER_CITY = "21625"
EAGLE_VILLAGE = "21425"
EAST_TROY_VILLAGE = "22100"
EASTMAN_VILLAGE = "21900"
EASTON_CDP = "21975"
EAU_CLAIRE_CITY = "22300"
EDEN_VILLAGE = "22475"
EDGAR_VILLAGE = "22550"
EDGERTON_CITY = "22575"
EDMUND_CDP = "22700"
EGG_HARBOR_VILLAGE = "22850"
ELAND_VILLAGE = "22975"
ELCHO_CDP = "23025"
ELDERON_VILLAGE = "23075"
ELEVA_VILLAGE = "23175"
ELK_MOUND_VILLAGE = "23325"
ELKHART_LAKE_VILLAGE = "23275"
ELKHORN_CITY = "23300"
ELLISON_BAY_CDP = "23475"
ELLSWORTH_VILLAGE = "23525"
ELM_GROVE_VILLAGE = "23575"
ELMWOOD_PARK_VILLAGE = "23725"
ELMWOOD_VILLAGE = "23700"
ELROY_CITY = "23800"
EMBARRASS_VILLAGE = "23850"
EMERALD_CDP = "23900"
ENDEAVOR_VILLAGE = "24075"
EPHRAIM_VILLAGE = "24150"
ETTRICK_VILLAGE = "24400"
EUREKA_CDP = "24475"
EVANSVILLE_CITY = "24550"
EXELAND_VILLAGE = "24700"
FAIRCHILD_VILLAGE = "24825"
FAIRWATER_VILLAGE = "25075"
FALL_CREEK_VILLAGE = "25125"
FALL_RIVER_VILLAGE = "25150"
FENNIMORE_CITY = "25600"
FENWOOD_VILLAGE = "25650"
FERRYVILLE_VILLAGE = "25725"
FITCHBURG_CITY = "25950"
FLORENCE_CDP = "26175"
FOND_DU_LAC_CITY = "26275"
FONTANA_ON_GENEVA_LAKE_VILLAGE = "26350"
FOOTVILLE_VILLAGE = "26400"
FOREST_JUNCTION_CDP = "26575"
FORESTVILLE_VILLAGE = "26625"
FORT_ATKINSON_CITY = "26675"
FOUNTAIN_CITY_CITY = "26850"
FOX_CROSSING_VILLAGE = "26982"
FOX_LAKE_CITY = "27000"
FOX_POINT_VILLAGE = "27075"
FRANCIS_CREEK_VILLAGE = "27125"
FRANKLIN_CITY = "27300"
FRANKS_FIELD_CDP = "27412"
FREDERIC_VILLAGE = "27500"
FREDONIA_VILLAGE = "27550"
FREMONT_VILLAGE = "27800"
FRENCH_ISLAND_CDP = "27875"
FRIENDSHIP_VILLAGE = "27950"
FRIESLAND_VILLAGE = "28000"
FULTON_CDP = "28050"
GALESVILLE_CITY = "28200"
GAYS_MILLS_VILLAGE = "28450"
GENOA_CITY_VILLAGE = "28675"
GENOA_VILLAGE = "28625"
GERMANTOWN_VILLAGE = "28875"
GIBBSVILLE_CDP = "28925"
GILLETT_CITY = "29050"
GILMAN_VILLAGE = "29175"
GILMANTON_CDP = "29200"
GLEN_FLORA_VILLAGE = "29475"
GLEN_HAVEN_CDP = "29500"
GLENBEULAH_VILLAGE = "29350"
GLENDALE_CITY = "29400"
GLENWOOD_CITY_CITY = "29625"
GLIDDEN_CDP = "29675"
GOODMAN_CDP = "29750"
GORDON_CDP = "29900"
GOTHAM_CDP = "29950"
GRAFTON_VILLAGE = "30000"
GRAND_MARSH_CDP = "30100"
GRAND_VIEW_CDP = "30150"
GRANTON_VILLAGE = "30425"
GRANTSBURG_VILLAGE = "30450"
GRATIOT_VILLAGE = "30575"
GREEN_BAY_CITY = "31000"
GREEN_LAKE_CITY = "31300"
GREEN_VALLEY_CDP = "31475"
GREENBUSH_CDP = "31075"
GREENDALE_VILLAGE = "31125"
GREENFIELD_CITY = "31175"
GREENLEAF_CDP = "31375"
GREENVILLE_VILLAGE = "31525"
GREENWOOD_CITY = "31575"
GRESHAM_VILLAGE = "31675"
HAGER_CITY_CDP = "31975"
HALES_CORNERS_VILLAGE = "32075"
HAMMOND_VILLAGE = "32325"
HANCOCK_VILLAGE = "32450"
HANOVER_CDP = "32550"
HARRISON_VILLAGE = "32790"
HARRISVILLE_CDP = "32950"
HARTFORD_CITY = "33000"
HARTLAND_VILLAGE = "33100"
HATFIELD_CDP = "33150"
HATLEY_VILLAGE = "33175"
HAUGEN_VILLAGE = "33225"
HAWKINS_VILLAGE = "33275"
HAYWARD_CITY = "33450"
HAZEL_GREEN_VILLAGE = "33500"
HEBRON_CDP = "33675"
HELENVILLE_CDP = "33825"
HERBSTER_CDP = "33975"
HEWITT_VILLAGE = "34250"
HIGHLAND_VILLAGE = "34450"
HILBERT_VILLAGE = "34575"
HILLSBORO_CITY = "34825"
HINGHAM_CDP = "35000"
HIXTON_VILLAGE = "35075"
HOBART_VILLAGE = "35150"
HOLCOMBE_CDP = "35225"
HOLLANDALE_VILLAGE = "35400"
HOLMEN_VILLAGE = "35450"
HORICON_CITY = "35750"
HORTONVILLE_VILLAGE = "35850"
HOULTON_CDP = "35900"
HOWARD_VILLAGE = "35950"
HOWARDS_GROVE_VILLAGE = "36025"
HUDSON_CITY = "36250"
HUMBIRD_CDP = "36400"
HURLEY_CITY = "36525"
HUSTISFORD_VILLAGE = "36625"
HUSTLER_VILLAGE = "36675"
INDEPENDENCE_CITY = "36800"
INGRAM_VILLAGE = "36925"
IOLA_VILLAGE = "37025"
IRON_BELT_CDP = "37125"
IRON_RIDGE_VILLAGE = "37150"
IRON_RIVER_CDP = "37175"
IRONTON_VILLAGE = "37225"
IXONIA_CDP = "37575"
JACKSON_VILLAGE = "37675"
JANESVILLE_CITY = "37825"
JEFFERSON_CITY = "37900"
JIM_FALLS_CDP = "38225"
JOHNSON_CREEK_VILLAGE = "38350"
JOLMAVILLE_CDP = "38487"
JUDA_CDP = "38600"
JUMP_RIVER_CDP = "38625"
JUNCTION_CITY_VILLAGE = "38650"
JUNEAU_CITY = "38675"
KAUKAUNA_CITY = "38800"
KEKOSKEE_VILLAGE = "38900"
KELLNERSVILLE_VILLAGE = "39000"
KENDALL_VILLAGE = "39150"
KENNAN_VILLAGE = "39175"
KENOSHA_CITY = "39225"
KESHENA_CDP = "39250"
KEWASKUM_VILLAGE = "39300"
KEWAUNEE_CITY = "39350"
KIEL_CITY = "39525"
KIELER_CDP = "39550"
KIMBERLY_VILLAGE = "39650"
KING_CDP = "39700"
KINGSTON_VILLAGE = "39750"
KNAPP_VILLAGE = "39975"
KNOWLTON_CDP = "40125"
KOHLER_VILLAGE = "40275"
KRAKOW_CDP = "40450"
KRONENWETTER_VILLAGE = "40550"
LA_CROSSE_CITY = "40775"
LA_FARGE_VILLAGE = "40875"
LA_VALLE_VILLAGE = "42825"
LAC_LA_BELLE_VILLAGE = "40750"
LAC_DU_FLAMBEAU_CDP = "40675"
LADYSMITH_CITY = "40850"
LAKE_ARROWHEAD_CDP = "41160"
LAKE_CAMELOT_CDP = "41210"
LAKE_DELTON_VILLAGE = "41300"
LAKE_GENEVA_CITY = "41450"
LAKE_HALLIE_VILLAGE = "41525"
LAKE_IVANHOE_CDP = "41560"
LAKE_KOSHKONONG_CDP = "41583"
LAKE_LORRAINE_CDP = "41645"
LAKE_MILLS_CITY = "41675"
LAKE_NEBAGAMON_VILLAGE = "41725"
LAKE_RIPLEY_CDP = "41765"
LAKE_SHERWOOD_CDP = "41772"
LAKE_TOMAHAWK_CDP = "41875"
LAKE_WAZEECHA_CDP = "41975"
LAKE_WISCONSIN_CDP = "42012"
LAKE_WISSOTA_CDP = "42025"
LAKEWOOD_CDP = "42050"
LANCASTER_CITY = "42250"
LANNON_VILLAGE = "42450"
LAONA_CDP = "42475"
LAUDERDALE_LAKES_CDP = "42805"
LEBANON_CDP = "43025"
LEGEND_LAKE_CDP = "43207"
LENA_VILLAGE = "43325"
LEOPOLIS_CDP = "43575"
LEWIS_CDP = "43725"
LILY_LAKE_CDP = "44033"
LIME_RIDGE_VILLAGE = "44225"
LINDEN_VILLAGE = "44625"
LITTLE_CHUTE_VILLAGE = "44950"
LITTLE_ROUND_LAKE_CDP = "45220"
LITTLE_STURGEON_CDP = "45225"
LIVINGSTON_VILLAGE = "45325"
LODI_CITY = "45350"
LOGANVILLE_VILLAGE = "45400"
LOHRVILLE_VILLAGE = "45425"
LOMIRA_VILLAGE = "45475"
LONE_ROCK_VILLAGE = "45575"
LONG_LAKE_CDP = "45600"
LOWELL_VILLAGE = "45950"
LOYAL_CITY = "46075"
LUBLIN_VILLAGE = "46150"
LUCK_VILLAGE = "46200"
LUXEMBURG_VILLAGE = "46400"
LYNDON_STATION_VILLAGE = "46600"
LYNXVILLE_VILLAGE = "46675"
LYONS_CDP = "46700"
MADISON_CITY = "48000"
MAIDEN_ROCK_VILLAGE = "48175"
MAINE_VILLAGE = "48225"
MANAWA_CITY = "48350"
MANITOWOC_CITY = "48500"
MAPLE_BLUFF_VILLAGE = "48750"
MARATHON_CITY_VILLAGE = "49100"
MARENGO_CDP = "49175"
MARIBEL_VILLAGE = "49250"
MARINETTE_CITY = "49300"
MARION_CITY = "49400"
MARKESAN_CITY = "49450"
MARQUETTE_VILLAGE = "49500"
MARSHALL_VILLAGE = "49575"
MARSHFIELD_CITY = "49675"
MASON_VILLAGE = "49900"
MATTOON_VILLAGE = "50000"
MAUSTON_CITY = "50025"
MAYVILLE_CITY = "50200"
MAZOMANIE_VILLAGE = "50225"
MCFARLAND_VILLAGE = "46850"
MEDFORD_CITY = "50425"
MELLEN_CITY = "50700"
MELROSE_VILLAGE = "50750"
MELVINA_VILLAGE = "50800"
MENASHA_CITY = "50825"
MENOMONEE_FALLS_VILLAGE = "51000"
MENOMONIE_CITY = "51025"
MEQUON_CITY = "51150"
MERCER_CDP = "51175"
MERRILL_CITY = "51250"
MERRILLAN_VILLAGE = "51300"
MERRIMAC_VILLAGE = "51325"
MERTON_VILLAGE = "51375"
MIDDLE_VILLAGE_CDP = "51617"
MIDDLETON_CITY = "51575"
MILLADORE_VILLAGE = "51875"
MILLSTON_CDP = "52025"
MILLTOWN_VILLAGE = "52075"
MILTON_CITY = "52200"
MILWAUKEE_CITY = "53000"
MINDORO_CDP = "53050"
MINERAL_POINT_CITY = "53100"
MINOCQUA_CDP = "53200"
MINONG_VILLAGE = "53250"
MISHICOT_VILLAGE = "53325"
MISSION_CDP = "53358"
MOLE_LAKE_CDP = "53500"
MONDOVI_CITY = "53600"
MONONA_CITY = "53675"
MONROE_CITY = "53750"
MONTELLO_CITY = "53875"
MONTFORT_VILLAGE = "53950"
MONTICELLO_VILLAGE = "54000"
MONTREAL_CITY = "54075"
MOSINEE_CITY = "54500"
MOUNT_CALVARY_VILLAGE = "54650"
MOUNT_HOPE_VILLAGE = "54675"
MOUNT_HOREB_VILLAGE = "54725"
MOUNT_PLEASANT_VILLAGE = "54875"
MOUNT_STERLING_VILLAGE = "54900"
MOUNTAIN_CDP = "54625"
MUKWONAGO_VILLAGE = "55050"
MUSCODA_VILLAGE = "55200"
MUSKEGO_CITY = "55275"
NASHOTAH_VILLAGE = "55550"
NAVARINO_CDP = "55650"
NECEDAH_VILLAGE = "55700"
NEENAH_CITY = "55750"
NEILLSVILLE_CITY = "55800"
NEKOOSA_CITY = "55875"
NELSON_VILLAGE = "55950"
NELSONVILLE_VILLAGE = "56000"
NEOPIT_CDP = "56050"
NEOSHO_VILLAGE = "56075"
NESHKORO_VILLAGE = "56125"
NEW_AUBURN_VILLAGE = "56350"
NEW_BERLIN_CITY = "56375"
NEW_GLARUS_VILLAGE = "56700"
NEW_HOLSTEIN_CITY = "56800"
NEW_LISBON_CITY = "56900"
NEW_LONDON_CITY = "56925"
NEW_MUNSTER_CDP = "57000"
NEW_ODANAH_CDP = "57008"
NEW_POST_CDP = "57050"
NEW_RICHMOND_CITY = "57100"
NEWALD_CDP = "56250"
NEWBURG_VILLAGE = "56450"
NIAGARA_CITY = "57325"
NICHOLS_VILLAGE = "57375"
NORTH_BAY_VILLAGE = "57700"
NORTH_FOND_DU_LAC_VILLAGE = "58000"
NORTH_FREEDOM_VILLAGE = "58025"
NORTH_HUDSON_VILLAGE = "58050"
NORTH_LAKE_CDP = "58100"
NORTH_PRAIRIE_VILLAGE = "58400"
NORTHPORT_CDP = "58375"
NORWALK_VILLAGE = "58575"
OAK_CREEK_CITY = "58800"
OAKDALE_VILLAGE = "58850"
OAKFIELD_VILLAGE = "58900"
OCONOMOWOC_LAKE_VILLAGE = "59300"
OCONOMOWOC_CITY = "59250"
OCONTO_FALLS_CITY = "59400"
OCONTO_CITY = "59350"
ODANAH_CDP = "59450"
OGDENSBURG_VILLAGE = "59475"
OGEMA_CDP = "59500"
OKAUCHEE_LAKE_CDP = "59650"
OLIVER_VILLAGE = "59800"
OMRO_CITY = "59875"
ONALASKA_CITY = "59925"
ONTARIO_VILLAGE = "60075"
OOSTBURG_VILLAGE = "60100"
OREGON_VILLAGE = "60200"
ORFORDVILLE_VILLAGE = "60250"
OSCEOLA_VILLAGE = "60450"
OSHKOSH_CITY = "60500"
OSSEO_CITY = "60575"
OWEN_CITY = "60825"
OXFORD_VILLAGE = "60875"
PAAC_CIINAK_CDP = "60912"
PACKWAUKEE_CDP = "60950"
PADDOCK_LAKE_VILLAGE = "60975"
PALMYRA_VILLAGE = "61025"
PARDEEVILLE_VILLAGE = "61100"
PARK_FALLS_CITY = "61200"
PARK_RIDGE_VILLAGE = "61325"
PATCH_GROVE_VILLAGE = "61425"
PELLA_CDP = "61675"
PEMBINE_CDP = "61750"
PENCE_CDP = "61800"
PEPIN_VILLAGE = "61925"
PESHTIGO_CITY = "62175"
PEWAUKEE_CITY = "62240"
PEWAUKEE_VILLAGE = "62250"
PHILLIPS_CITY = "62450"
PIGEON_FALLS_VILLAGE = "62675"
PINE_RIVER_CDP = "62975"
PITTSVILLE_CITY = "63100"
PLAIN_VILLAGE = "63125"
PLAINFIELD_VILLAGE = "63150"
PLATTEVILLE_CITY = "63250"
PLEASANT_PRAIRIE_VILLAGE = "63300"
PLOVER_VILLAGE = "63525"
PLUM_CITY_VILLAGE = "63600"
PLYMOUTH_CITY = "63700"
POLONIA_CDP = "63925"
POPLAR_VILLAGE = "63975"
PORT_EDWARDS_VILLAGE = "64175"
PORT_WASHINGTON_CITY = "64450"
PORT_WING_CDP = "64500"
PORTAGE_CITY = "64100"
POST_LAKE_CDP = "64550"
POTOSI_VILLAGE = "64625"
POTTER_LAKE_CDP = "64700"
POTTER_VILLAGE = "64675"
POUND_VILLAGE = "64750"
POWERS_LAKE_CDP = "64825"
POY_SIPPI_CDP = "64950"
POYNETTE_VILLAGE = "64900"
PRAIRIE_FARM_VILLAGE = "65150"
PRAIRIE_DU_CHIEN_CITY = "65050"
PRAIRIE_DU_SAC_VILLAGE = "65100"
PRENTICE_VILLAGE = "65325"
PRESCOTT_CITY = "65375"
PRINCETON_CITY = "65600"
PULASKI_VILLAGE = "65675"
PULCIFER_CDP = "65725"
RACINE_CITY = "66000"
RADISSON_VILLAGE = "66050"
RANDOLPH_VILLAGE = "66150"
RANDOM_LAKE_VILLAGE = "66200"
RAYMOND_VILLAGE = "66350"
READSTOWN_VILLAGE = "66450"
REDGRANITE_VILLAGE = "66625"
REEDSBURG_CITY = "66800"
REEDSVILLE_VILLAGE = "66875"
REESEVILLE_VILLAGE = "66900"
RESERVE_CDP = "67050"
REWEY_VILLAGE = "67100"
RHINELANDER_CITY = "67200"
RIB_LAKE_VILLAGE = "67275"
RIB_MOUNTAIN_CDP = "67320"
RICE_LAKE_CITY = "67350"
RICHFIELD_VILLAGE = "67475"
RICHLAND_CENTER_CITY = "67625"
RIDGELAND_VILLAGE = "67800"
RIDGEWAY_VILLAGE = "67875"
RIO_VILLAGE = "68100"
RIPON_CITY = "68175"
RIVER_FALLS_CITY = "68275"
RIVER_HILLS_VILLAGE = "68325"
ROBERTS_VILLAGE = "68475"
ROCHESTER_VILLAGE = "68550"
ROCK_FALLS_CDP = "68800"
ROCK_SPRINGS_VILLAGE = "68975"
ROCKDALE_VILLAGE = "68725"
ROCKLAND_VILLAGE = "68900"
ROME_CDP = "69300"
ROSENDALE_VILLAGE = "69525"
ROSHOLT_VILLAGE = "69575"
ROTHSCHILD_VILLAGE = "69725"
RUBICON_CDP = "69950"
RUDOLPH_VILLAGE = "70000"
SALEM_LAKES_VILLAGE = "71163"
SAND_PILLOW_CDP = "71512"
SANDY_HOOK_CDP = "71585"
SAUK_CITY_VILLAGE = "71650"
SAUKVILLE_VILLAGE = "71700"
SAXON_CDP = "71850"
SAYNER_CDP = "71950"
SCANDINAVIA_VILLAGE = "71975"
SCHOFIELD_CITY = "72150"
SENECA_CDP = "72475"
SEXTONVILLE_CDP = "72650"
SEYMOUR_CDP = "72670"
SEYMOUR_CITY = "72725"
SHARON_VILLAGE = "72875"
SHAWANO_CITY = "72925"
SHEBOYGAN_FALLS_CITY = "73025"
SHEBOYGAN_CITY = "72975"
SHELDON_VILLAGE = "73175"
SHELL_LAKE_CITY = "73200"
SHERWOOD_VILLAGE = "73525"
SHIOCTON_VILLAGE = "73625"
SHOPIERE_CDP = "73675"
SHOREWOOD_HILLS_VILLAGE = "73750"
SHOREWOOD_VILLAGE = "73725"
SHULLSBURG_CITY = "73825"
SIREN_VILLAGE = "74175"
SISTER_BAY_VILLAGE = "74225"
SLINGER_VILLAGE = "74400"
SOBIESKI_CDP = "74500"
SOLDIERS_GROVE_VILLAGE = "74550"
SOLON_SPRINGS_VILLAGE = "74575"
SOMERS_VILLAGE = "74625"
SOMERSET_VILLAGE = "74675"
SOUTH_MILWAUKEE_CITY = "75125"
SOUTH_WAYNE_VILLAGE = "75275"
SPARTA_CITY = "75325"
SPENCER_VILLAGE = "75400"
SPOONER_CITY = "75625"
SPRING_GREEN_VILLAGE = "76025"
SPRING_VALLEY_VILLAGE = "76300"
SPRINGBROOK_CDP = "75775"
SPRINGFIELD_CDP = "75975"
ST_CLOUD_VILLAGE = "70500"
ST_CROIX_FALLS_CITY = "70550"
ST_FRANCIS_CITY = "70650"
ST_JOSEPH_CDP = "70800"
ST_NAZIANZ_VILLAGE = "71025"
ST_PETER_CDP = "71050"
STANLEY_CITY = "76625"
STAR_PRAIRIE_VILLAGE = "76825"
STETSONVILLE_VILLAGE = "77100"
STEUBEN_VILLAGE = "77175"
STEVENS_POINT_CITY = "77200"
STOCKBRIDGE_VILLAGE = "77400"
STOCKHOLM_VILLAGE = "77475"
STODDARD_VILLAGE = "77550"
STONE_LAKE_CDP = "77625"
STOUGHTON_CITY = "77675"
STRATFORD_VILLAGE = "77750"
STRUM_VILLAGE = "77825"
STURGEON_BAY_CITY = "77875"
STURTEVANT_VILLAGE = "77925"
SUAMICO_VILLAGE = "77975"
SULLIVAN_VILLAGE = "78175"
SUMMIT_LAKE_CDP = "78425"
SUMMIT_VILLAGE = "78375"
SUN_PRAIRIE_CITY = "78600"
SUPERIOR_CITY = "78650"
SUPERIOR_VILLAGE = "78660"
SURING_VILLAGE = "78725"
SUSSEX_VILLAGE = "78750"
TAINTER_LAKE_CDP = "78980"
TAYCHEEDAH_CDP = "79100"
TAYLOR_VILLAGE = "79150"
TENNYSON_VILLAGE = "79250"
THERESA_VILLAGE = "79375"
THIENSVILLE_VILLAGE = "79475"
THORNTON_CDP = "79600"
THORP_CITY = "79625"
THREE_LAKES_CDP = "79675"
TICHIGAN_CDP = "79740"
TIGERTON_VILLAGE = "79825"
TILLEDA_CDP = "79900"
TOMAH_CITY = "80075"
TOMAHAWK_CITY = "80125"
TONY_VILLAGE = "80225"
TOWNSEND_CDP = "80300"
TREGO_CDP = "80425"
TREMPEALEAU_VILLAGE = "80475"
TUNNEL_CITY_CDP = "81025"
TURTLE_LAKE_CDP = "81090"
TURTLE_LAKE_VILLAGE = "81075"
TUSTIN_CDP = "81150"
TWIN_LAKES_VILLAGE = "81250"
TWO_RIVERS_CITY = "81325"
UNION_CENTER_VILLAGE = "81725"
UNION_GROVE_VILLAGE = "81775"
UNITY_VILLAGE = "81850"
VALDERS_VILLAGE = "82200"
VAN_DYNE_CDP = "82450"
VERNON_VILLAGE = "82575"
VERONA_CITY = "82600"
VESPER_VILLAGE = "82650"
VIOLA_VILLAGE = "82900"
VIROQUA_CITY = "82925"
WABENO_CDP = "83000"
WALDO_VILLAGE = "83100"
WALES_VILLAGE = "83175"
WALWORTH_VILLAGE = "83250"
WARRENS_VILLAGE = "83450"
WASHBURN_CITY = "83525"
WATERFORD_VILLAGE = "83825"
WATERLOO_CITY = "83925"
WATERTOWN_CITY = "83975"
WAUBEKA_CDP = "84150"
WAUKAU_CDP = "84200"
WAUKESHA_CITY = "84250"
WAUKESHA_VILLAGE = "84275"
WAUMANDEE_CDP = "84300"
WAUNAKEE_VILLAGE = "84350"
WAUPACA_CITY = "84375"
WAUPUN_CITY = "84425"
WAUSAU_CITY = "84475"
WAUSAUKEE_VILLAGE = "84525"
WAUTOMA_CITY = "84625"
WAUWATOSA_CITY = "84675"
WAUZEKA_VILLAGE = "84725"
WEBSTER_VILLAGE = "85025"
WEST_ALLIS_CITY = "85300"
WEST_BARABOO_VILLAGE = "85325"
WEST_BEND_CITY = "85350"
WEST_MILWAUKEE_VILLAGE = "85875"
WEST_SALEM_VILLAGE = "86275"
WESTBORO_CDP = "85425"
WESTBY_CITY = "85475"
WESTFIELD_VILLAGE = "85575"
WESTON_VILLAGE = "86025"
WEYAUWEGA_CITY = "86400"
WEYERHAEUSER_VILLAGE = "86450"
WHEELER_VILLAGE = "86575"
WHITE_LAKE_VILLAGE = "86750"
WHITEFISH_BAY_VILLAGE = "86700"
WHITEHALL_CITY = "86725"
WHITELAW_VILLAGE = "86775"
WHITEWATER_CITY = "86925"
WHITING_VILLAGE = "86975"
WHITTLESEY_CDP = "87000"
WILD_ROSE_VILLAGE = "87075"
WILLIAMS_BAY_VILLAGE = "87200"
WILSON_VILLAGE = "87475"
WILTON_VILLAGE = "87525"
WINCHESTER_CDP = "87625"
WIND_LAKE_CDP = "87675"
WIND_POINT_VILLAGE = "87700"
WINDSOR_VILLAGE = "87725"
WINNECONNE_VILLAGE = "87900"
WINTER_VILLAGE = "87975"
WIOTA_CDP = "88025"
WISCONSIN_DELLS_CITY = "88150"
WISCONSIN_RAPIDS_CITY = "88200"
WITHEE_VILLAGE = "88275"
WITTENBERG_VILLAGE = "88325"
WONEWOC_VILLAGE = "88500"
WOODFORD_CDP = "88675"
WOODMAN_VILLAGE = "88825"
WOODRUFF_CDP = "88925"
WOODVILLE_VILLAGE = "89025"
WRIGHTSTOWN_VILLAGE = "89150"
WYEVILLE_VILLAGE = "89275"
WYOCENA_VILLAGE = "89300"
YORKVILLE_VILLAGE = "89550"
YUBA_VILLAGE = "89625"
ZOAR_CDP = "89760"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in New Hampshire."""


ALTON_CDP = "00980"
AMHERST_CDP = "01220"
ANTRIM_CDP = "01620"
ASHLAND_CDP = "01940"
BARTLETT_CDP = "03620"
BELMONT_CDP = "04660"
BENNINGTON_CDP = "04820"
BERLIN_CITY = "05140"
BETHLEHEM_CDP = "05380"
BLODGETT_LANDING_CDP = "06020"
BRADFORD_CDP = "06900"
BRISTOL_CDP = "07620"
CANAAN_CDP = "08900"
CENTER_OSSIPEE_CDP = "10820"
CENTER_SANDWICH_CDP = "10900"
CHARLESTOWN_CDP = "11300"
CLAREMONT_CITY = "12900"
COLEBROOK_CDP = "13700"
CONCORD_CITY = "14200"
CONTOOCOOK_CDP = "14340"
CONWAY_CDP = "14580"
DERRY_CDP = "17860"
DOVER_CITY = "18820"
DURHAM_CDP = "19620"
EAST_MERRIMACK_CDP = "21780"
ENFIELD_CDP = "24260"
EPPING_CDP = "24580"
EXETER_CDP = "25300"
FARMINGTON_CDP = "25940"
FRANCESTOWN_CDP = "27060"
FRANKLIN_CITY = "27380"
GOFFSTOWN_CDP = "29780"
GORHAM_CDP = "30180"
GREENVILLE_CDP = "31860"
GROVETON_CDP = "32260"
HAMPTON_BEACH_CDP = "33140"
HAMPTON_CDP = "32980"
HANCOCK_CDP = "33620"
HANOVER_CDP = "33780"
HENNIKER_CDP = "35460"
HILLSBOROUGH_CDP = "36020"
HINSDALE_CDP = "36580"
HOOKSETT_CDP = "37220"
HUDSON_CDP = "37860"
JAFFREY_CDP = "38420"
KEENE_CITY = "39300"
KLONDIKE_CORNER_CDP = "40120"
LACONIA_CITY = "40180"
LANCASTER_CDP = "40340"
LEBANON_CITY = "41300"
LINCOLN_CDP = "41780"
LISBON_CDP = "41940"
LITTLETON_CDP = "42500"
LONDONDERRY_CDP = "43140"
LOUDON_CDP = "43300"
MANCHESTER_CITY = "45140"
MARLBOROUGH_CDP = "45380"
MELVIN_VILLAGE_CDP = "46980"
MEREDITH_CDP = "47060"
MILFORD_CDP = "47940"
MILTON_CDP = "48580"
MILTON_MILLS_CDP = "48740"
MOUNTAIN_LAKES_CDP = "49600"
NASHUA_CITY = "50260"
NEW_BOSTON_CDP = "50660"
NEW_HAMPTON_CDP = "51460"
NEW_LONDON_CDP = "52020"
NEWFIELDS_CDP = "51300"
NEWMARKET_CDP = "52260"
NEWPORT_CDP = "52500"
NORTH_CONWAY_CDP = "53860"
NORTH_HAVERHILL_CDP = "54740"
NORTH_WALPOLE_CDP = "56420"
NORTH_WOODSTOCK_CDP = "57220"
PETERBOROUGH_CDP = "60500"
PINARDVILLE_CDP = "61220"
PITTSFIELD_CDP = "61860"
PLAINFIELD_CDP = "62260"
PLYMOUTH_CDP = "62580"
PORTSMOUTH_CITY = "62900"
RAYMOND_CDP = "63940"
ROCHESTER_CITY = "65140"
SANBORNVILLE_CDP = "67460"
SEABROOK_BEACH_CDP = "68340"
SOMERSWORTH_CITY = "69940"
SOUTH_HOOKSETT_CDP = "71220"
SUISSEVALE_CDP = "74780"
SUNCOOK_CDP = "75140"
TILTON_NORTHFIELD_CDP = "77100"
TROY_CDP = "77300"
UNION_CDP = "77780"
WALPOLE_CDP = "78340"
WARNER_CDP = "78500"
WEST_STEWARTSTOWN_CDP = "83620"
WEST_SWANZEY_CDP = "83700"
WHITEFIELD_CDP = "84340"
WILTON_CDP = "85140"
WINCHESTER_CDP = "85460"
WOLFEBORO_CDP = "86340"
WOODSVILLE_CDP = "87140"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Puerto Rico."""


ACEITUNAS_COMUNIDAD = "00186"
ADJUNTAS_ZONA_URBANA = "00358"
AGUADA_ZONA_URBANA = "00616"
AGUADILLA_ZONA_URBANA = "00745"
AGUAS_BUENAS_ZONA_URBANA = "00874"
AGUAS_CLARAS_COMUNIDAD = "01003"
AGUILITA_COMUNIDAD = "01089"
AIBONITO_ZONA_URBANA = "01218"
ALIANZA_COMUNIDAD = "01863"
ANIMAS_COMUNIDAD = "03024"
ANON_RAICES_COMUNIDAD = "03174"
ANTON_RUIZ_COMUNIDAD = "03196"
ARECIBO_ZONA_URBANA = "03368"
ARROYO_ZONA_URBANA = "03927"
ANASCO_ZONA_URBANA = "02680"
BAIROA_LA_VEINTICINCO_COMUNIDAD = "04620"
BAJADERO_COMUNIDAD = "04658"
BAJANDAS_COMUNIDAD = "04701"
BARAHONA_COMUNIDAD = "05217"
BARCELONETA_ZONA_URBANA = "05346"
BARRANQUITAS_ZONA_URBANA = "05690"
BARTOLO_COMUNIDAD = "06421"
BAYAMON_COMUNIDAD = "06679"
BAYAMON_ZONA_URBANA = "06593"
BENITEZ_COMUNIDAD = "07496"
BETANCES_COMUNIDAD = "07668"
BOQUERON_COMUNIDAD_CABO_ROJO_MUNICIPIO = "07969"
BOQUERON_COMUNIDAD_LAS_PIEDRAS_MUNICIPIO = "08099"
BRENAS_COMUNIDAD = "08700"
BRISAS_DEL_CAMPANERO_COMUNIDAD = "08722"
BUENA_VISTA_COMUNIDAD_ARROYO_MUNICIPIO = "09087"
BUENA_VISTA_COMUNIDAD_HUMACAO_MUNICIPIO = "09250"
BÚFALO_COMUNIDAD = "09603"
CABO_ROJO_ZONA_URBANA = "09861"
CABAN_COMUNIDAD = "09689"
CACAO_COMUNIDAD = "10048"
CAGUAS_ZONA_URBANA = "10334"
CALZADA_COMUNIDAD = "11151"
CAMBALACHE_COMUNIDAD = "11345"
CAMPANILLA_COMUNIDAD = "11581"
CAMPANILLAS_COMUNIDAD = "11597"
CAMPO_RICO_COMUNIDAD = "11710"
CAMUY_ZONA_URBANA = "11925"
CANDELARIA_ARENAS_COMUNIDAD = "12560"
CANDELARIA_COMUNIDAD = "12441"
CANDELERO_ABAJO_COMUNIDAD = "12568"
CANDELERO_ARRIBA_COMUNIDAD = "12613"
CANOVANILLAS_COMUNIDAD = "13065"
CANOVANAS_ZONA_URBANA = "12828"
CAPITANEJO_COMUNIDAD = "13925"
CAROLINA_ZONA_URBANA = "14290"
CARRIZALES_COMUNIDAD = "14634"
CATANO_ZONA_URBANA = "15193"
CAYEY_ZONA_URBANA = "15494"
CAYUCO_COMUNIDAD = "15623"
CANO_MARTIN_PENA_COMUNIDAD = "12806"
CEIBA_COMUNIDAD = "16139"
CEIBA_ZONA_URBANA = "15924"
CELADA_COMUNIDAD = "16440"
CENTRAL_AGUIRRE_COMUNIDAD = "16526"
CERRILLOS_HOYOS_COMUNIDAD = "17050"
CIALES_ZONA_URBANA = "17773"
CIDRA_ZONA_URBANA = "18074"
COAMO_ZONA_URBANA = "18719"
COCO_COMUNIDAD = "18891"
COMERIO_ZONA_URBANA = "19665"
COMUNAS_COMUNIDAD = "19837"
COQUI_COMUNIDAD = "20310"
CORAZON_COMUNIDAD = "20353"
CORCOVADO_COMUNIDAD = "20482"
COROZAL_ZONA_URBANA = "20783"
CORRAL_VIEJO_COMUNIDAD = "20998"
COTO_LAUREL_COMUNIDAD = "21213"
COTO_NORTE_COMUNIDAD = "21385"
CULEBRA_ZONA_URBANA = "22589"
DAGUAO_COMUNIDAD = "23062"
DEL_CARMEN_COMUNIDAD = "23341"
DORADO_ZONA_URBANA = "24008"
DUQUE_COMUNIDAD = "24395"
EL_COMBATE_COMUNIDAD = "24954"
EL_MANGO_COMUNIDAD = "25556"
EL_NEGRO_COMUNIDAD = "25685"
EL_OJO_COMUNIDAD = "25771"
EL_PARAISO_COMUNIDAD = "25835"
EL_TUMBAO_COMUNIDAD = "26287"
EL_VEINTISÉIS_COMUNIDAD = "26362"
EMAJAGUA_COMUNIDAD = "26502"
ESPERANZA_COMUNIDAD = "27190"
ESPINO_COMUNIDAD = "27263"
FAJARDO_ZONA_URBANA = "27964"
FERRER_COMUNIDAD = "28367"
FLORIDA_ZONA_URBANA = "28824"
FRONTON_COMUNIDAD = "29682"
FRANQUEZ_COMUNIDAD = "29555"
FUIG_COMUNIDAD = "29727"
G_L_GARCIA_COMUNIDAD = "30544"
GALATEO_COMUNIDAD = "29813"
GARROCHALES_COMUNIDAD = "30372"
GUAYABAL_COMUNIDAD = "31877"
GUAYAMA_ZONA_URBANA = "32221"
GUAYANILLA_ZONA_URBANA = "32307"
GUAYNABO_ZONA_URBANA = "32522"
GURABO_ZONA_URBANA = "32823"
GUANICA_ZONA_URBANA = "31189"
H_RIVERA_COLON_COMUNIDAD = "35403"
HACIENDA_SAN_JOSÉ_COMUNIDAD = "33184"
HATILLO_ZONA_URBANA = "33296"
HATO_ARRIBA_COMUNIDAD = "33597"
HATO_CANDAL_COMUNIDAD = "33683"
HATO_VIEJO_COMUNIDAD = "34242"
HONDURAS_COMUNIDAD = "34914"
HORMIGUEROS_ZONA_URBANA = "35059"
HUMACAO_ZONA_URBANA = "35532"
IMBÉRY_COMUNIDAD = "35962"
INDIOS_COMUNIDAD = "36177"
INGENIO_COMUNIDAD = "36263"
ISABELA_ZONA_URBANA = "36478"
ISLETA_COMUNIDAD = "36779"
JAGUAL_COMUNIDAD = "37166"
JAGUAS_COMUNIDAD = "37336"
JAUCA_COMUNIDAD = "38241"
JAYUYA_ZONA_URBANA = "38370"
JOBOS_COMUNIDAD = "38671"
JUANA_DIAZ_ZONA_URBANA = "38972"
JUNCAL_COMUNIDAD = "39470"
JUNCOS_ZONA_URBANA = "39574"
LA_ALIANZA_COMUNIDAD = "39875"
LA_DOLORES_COMUNIDAD = "40348"
LA_FERMINA_COMUNIDAD = "40563"
LA_LIGA_COMUNIDAD = "41274"
LA_LUISA_COMUNIDAD = "41294"
LA_PARGUERA_COMUNIDAD = "41767"
LA_PICA_COMUNIDAD = "41810"
LA_PLAYA_COMUNIDAD = "42068"
LA_PLENA_COMUNIDAD = "42197"
LA_YUCA_COMUNIDAD = "45170"
LAJAS_ZONA_URBANA = "40950"
LAMBOGLIA_COMUNIDAD = "41466"
LARES_ZONA_URBANA = "42498"
LAS_CAROLINAS_COMUNIDAD = "42842"
LAS_CROABAS_COMUNIDAD = "43057"
LAS_GAVIOTAS_COMUNIDAD = "43294"
LAS_MARIAS_COMUNIDAD = "43702"
LAS_MARIAS_ZONA_URBANA = "43788"
LAS_OCHENTA_COMUNIDAD = "44003"
LAS_OLLAS_COMUNIDAD = "44089"
LAS_PIEDRAS_ZONA_URBANA = "44390"
LASSALLE_COMUNIDAD = "44507"
LIBORIO_NEGRON_TORRES_COMUNIDAD = "45379"
LLUVERAS_COMUNIDAD = "46282"
LOMAS_VERDES_COMUNIDAD = "46800"
LOMAS_COMUNIDAD = "46626"
LOS_HÉROES_COMUNIDAD = "46960"
LOS_LLANOS_COMUNIDAD = "47013"
LOS_PANES_COMUNIDAD = "47336"
LOS_PRADOS_COMUNIDAD = "47422"
LOIZA_ZONA_URBANA = "46368"
LUIS_LLORÉNS_TORRES_COMUNIDAD = "47615"
LUIS_M_CINTRON_COMUNIDAD = "47701"
LUQUILLO_ZONA_URBANA = "47787"
LUYANDO_COMUNIDAD = "47873"
MAGAS_ARRIBA_COMUNIDAD = "48604"
MAGUAYO_COMUNIDAD = "48862"
MANATI_ZONA_URBANA = "50152"
MANSION_DEL_MAR_COMUNIDAD = "50260"
MANSION_DEL_SOL_COMUNIDAD = "50270"
MARIANO_COLON_COMUNIDAD = "51055"
MARICAO_ZONA_URBANA = "51270"
MARTORELL_COMUNIDAD = "51657"
MARUENO_COMUNIDAD = "51700"
MARIA_ANTONIA_COMUNIDAD = "50754"
MAUNABO_ZONA_URBANA = "52345"
MAYAGUEZ_ZONA_URBANA = "52431"
MIRANDA_COMUNIDAD = "53678"
MOCA_ZONA_URBANA = "53807"
MONSERRATE_COMUNIDAD = "53979"
MONTE_GRANDE_COMUNIDAD = "54366"
MONTE_VERDE_COMUNIDAD = "54688"
MORA_COMUNIDAD = "54882"
MOROVIS_ZONA_URBANA = "55097"
MUCARABONES_COMUNIDAD = "55355"
NAGUABO_ZONA_URBANA = "55828"
NARANJITO_ZONA_URBANA = "56129"
OLIMPO_COMUNIDAD = "57075"
OROCOVIS_ZONA_URBANA = "57290"
PABELLONES_COMUNIDAD = "57612"
PAJONAL_COMUNIDAD = "57862"
PALMA_SOLA_COMUNIDAD = "58613"
PALMAREJO_COMUNIDAD_COAMO_MUNICIPIO = "57978"
PALMAREJO_COMUNIDAD_COROZAL_MUNICIPIO = "58064"
PALMAREJO_COMUNIDAD_LAJAS_MUNICIPIO = "58150"
PALMAS_COMUNIDAD = "58365"
PALMAS_DEL_MAR_COMUNIDAD = "58602"
PALMER_COMUNIDAD = "58666"
PALO_SECO_COMUNIDAD = "59139"
PALOMAS_COMUNIDAD_COMERIO_MUNICIPIO = "58967"
PALOMAS_COMUNIDAD_YAUCO_MUNICIPIO = "59053"
PARCELAS_LA_MILAGROSA_COMUNIDAD = "59420"
PARCELAS_MANDRY_COMUNIDAD = "59422"
PARCELAS_NUEVAS_COMUNIDAD = "59425"
PARCELAS_PENUELAS_COMUNIDAD = "59440"
PARCELAS_VIEJAS_BORINQUEN_COMUNIDAD = "59450"
PARCELAS_DE_NAVARRO_COMUNIDAD = "59386"
PASTOS_COMUNIDAD = "60257"
PATILLAS_ZONA_URBANA = "60472"
PENA_POBRE_COMUNIDAD = "60945"
PENUELAS_ZONA_URBANA = "61074"
PIEDRA_AGUZA_COMUNIDAD = "61545"
PIEDRA_GORDA_COMUNIDAD = "61590"
PINAS_COMUNIDAD = "61977"
PLAYA_FORTUNA_COMUNIDAD = "63310"
PLAYITA_CORTADA_COMUNIDAD = "63568"
PLAYITA_COMUNIDAD_SALINAS_MUNICIPIO = "63503"
PLAYITA_COMUNIDAD_YABUCOA_MUNICIPIO = "63525"
POLE_OJEA_COMUNIDAD = "63697"
PONCE_ZONA_URBANA = "63820"
POTALA_PASTILLO_COMUNIDAD = "64127"
PUEBLITO_DEL_CARMEN_COMUNIDAD = "64400"
PUEBLITO_DEL_RIO_COMUNIDAD = "64500"
PUERTO_REAL_COMUNIDAD = "65589"
PUNTA_SANTIAGO_COMUNIDAD = "66492"
PAJAROS_COMUNIDAD = "57806"
QUEBRADA_PRIETA_COMUNIDAD = "67675"
QUEBRADA_COMUNIDAD = "66660"
QUEBRADA_DEL_AGUA_COMUNIDAD = "67200"
QUEBRADILLAS_ZONA_URBANA = "68040"
RAFAEL_CAPO_COMUNIDAD = "68513"
RAFAEL_GONZALEZ_COMUNIDAD = "68556"
RAFAEL_HERNANDEZ_COMUNIDAD = "68599"
RAMOS_COMUNIDAD = "68771"
RINCON_COMUNIDAD = "69488"
RINCON_ZONA_URBANA = "69588"
RODRIGUEZ_HEVIA_COMUNIDAD = "71996"
ROSA_SANCHEZ_COMUNIDAD = "72555"
RIO_BLANCO_COMUNIDAD = "70448"
RIO_CANAS_ABAJO_COMUNIDAD = "70706"
RIO_GRANDE_ZONA_URBANA = "71136"
RIO_LAJAS_COMUNIDAD = "71437"
SABANA_ENEAS_COMUNIDAD = "73372"
SABANA_GRANDE_ZONA_URBANA = "73544"
SABANA_HOYOS_COMUNIDAD = "73716"
SABANA_SECA_COMUNIDAD = "74189"
SABANA_COMUNIDAD = "73200"
SALINAS_ZONA_URBANA = "74877"
SAN_ANTONIO_COMUNIDAD_AGUADILLA_MUNICIPIO = "75608"
SAN_ANTONIO_COMUNIDAD_DORADO_MUNICIPIO = "75694"
SAN_ANTONIO_COMUNIDAD_QUEBRADILLAS_MUNICIPIO = "75780"
SAN_GERMAN_ZONA_URBANA = "76167"
SAN_ISIDRO_COMUNIDAD = "76339"
SAN_JOSÉ_COMUNIDAD = "76683"
SAN_JUAN_ZONA_URBANA = "76770"
SAN_LORENZO_ZONA_URBANA = "77027"
SAN_SEBASTIAN_ZONA_URBANA = "77500"
SANTA_BARBARA_COMUNIDAD = "77672"
SANTA_CLARA_COMUNIDAD = "77826"
SANTA_ISABEL_ZONA_URBANA = "78145"
SANTA_MARIA_COMUNIDAD = "78317"
SANTO_DOMINGO_COMUNIDAD = "79564"
STELLA_COMUNIDAD = "80596"
SUAREZ_COMUNIDAD = "80639"
TALLABOA_ALTA_COMUNIDAD = "81456"
TALLABOA_COMUNIDAD = "81413"
TIBES_COMUNIDAD = "82055"
TIBURONES_COMUNIDAD = "82125"
TIERRAS_NUEVAS_PONIENTE_COMUNIDAD = "82187"
TOA_ALTA_ZONA_URBANA = "82488"
TOA_BAJA_ZONA_URBANA = "82617"
TOAVILLE_COMUNIDAD = "82692"
TOMAS_DE_CASTRO_COMUNIDAD = "82875"
TRUJILLO_ALTO_ZONA_URBANA = "83606"
UTUADO_ZONA_URBANA = "84509"
VALLE_HILL_COMUNIDAD = "84917"
VAYAS_COMUNIDAD = "85025"
VEGA_ALTA_ZONA_URBANA = "85197"
VEGA_BAJA_ZONA_URBANA = "85326"
VIEQUES_COMUNIDAD = "85971"
VIEQUES_ZONA_URBANA = "86014"
VILLA_CALMA_COMUNIDAD = "86250"
VILLA_ESPERANZA_COMUNIDAD = "86584"
VILLA_HUGO_I_COMUNIDAD = "86788"
VILLA_HUGO_II_COMUNIDAD = "86796"
VILLA_QUINTERO_COMUNIDAD = "87240"
VILLA_SIN_MIEDO_COMUNIDAD = "87282"
VILLA_DE_SABANA_COMUNIDAD = "86509"
VILLALBA_ZONA_URBANA = "86831"
VILLAS_DEL_SOL_COMUNIDAD = "87272"
VOLADORAS_COMUNIDAD = "87638"
VAZQUEZ_COMUNIDAD = "85111"
YABUCOA_ZONA_URBANA = "87863"
YAUCO_ZONA_URBANA = "88035"
YAUREL_COMUNIDAD = "88121"
YEGUADA_COMUNIDAD = "88293"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Virginia."""


ACCOMACK = "001"
ALBEMARLE = "003"
ALEXANDRIA_CITY = "510"
ALLEGHANY = "005"
AMELIA = "007"
AMHERST = "009"
APPOMATTOX = "011"
ARLINGTON = "013"
AUGUSTA = "015"
BATH = "017"
BEDFORD = "019"
BLAND = "021"
BOTETOURT = "023"
BRISTOL_CITY = "520"
BRUNSWICK = "025"
BUCHANAN = "027"
BUCKINGHAM = "029"
BUENA_VISTA_CITY = "530"
CAMPBELL = "031"
CAROLINE = "033"
CARROLL = "035"
CHARLES_CITY = "036"
CHARLOTTE = "037"
CHARLOTTESVILLE_CITY = "540"
CHESAPEAKE_CITY = "550"
CHESTERFIELD = "041"
CLARKE = "043"
COLONIAL_HEIGHTS_CITY = "570"
COVINGTON_CITY = "580"
CRAIG = "045"
CULPEPER = "047"
CUMBERLAND = "049"
DANVILLE_CITY = "590"
DICKENSON = "051"
DINWIDDIE = "053"
EMPORIA_CITY = "595"
ESSEX = "057"
FAIRFAX = "059"
FAIRFAX_CITY = "600"
FALLS_CHURCH_CITY = "610"
FAUQUIER = "061"
FLOYD = "063"
FLUVANNA = "065"
FRANKLIN = "067"
FRANKLIN_CITY = "620"
FREDERICK = "069"
FREDERICKSBURG_CITY = "630"
GALAX_CITY = "640"
GILES = "071"
GLOUCESTER = "073"
GOOCHLAND = "075"
GRAYSON = "077"
GREENE = "079"
GREENSVILLE = "081"
HALIFAX = "083"
HAMPTON_CITY = "650"
HANOVER = "085"
HARRISONBURG_CITY = "660"
HENRICO = "087"
HENRY = "089"
HIGHLAND = "091"
HOPEWELL_CITY = "670"
ISLE_OF_WIGHT = "093"
JAMES_CITY = "095"
KING_GEORGE = "099"
KING_WILLIAM = "101"
KING_AND_QUEEN = "097"
LANCASTER = "103"
LEE = "105"
LEXINGTON_CITY = "678"
LOUDOUN = "107"
LOUISA = "109"
LUNENBURG = "111"
LYNCHBURG_CITY = "680"
MADISON = "113"
MANASSAS_PARK_CITY = "685"
MANASSAS_CITY = "683"
MARTINSVILLE_CITY = "690"
MATHEWS = "115"
MECKLENBURG = "117"
MIDDLESEX = "119"
MONTGOMERY = "121"
NELSON = "125"
NEW_KENT = "127"
NEWPORT_NEWS_CITY = "700"
NORFOLK_CITY = "710"
NORTHAMPTON = "131"
NORTHUMBERLAND = "133"
NORTON_CITY = "720"
NOTTOWAY = "135"
ORANGE = "137"
PAGE = "139"
PATRICK = "141"
PETERSBURG_CITY = "730"
PITTSYLVANIA = "143"
POQUOSON_CITY = "735"
PORTSMOUTH_CITY = "740"
POWHATAN = "145"
PRINCE_EDWARD = "147"
PRINCE_GEORGE = "149"
PRINCE_WILLIAM = "153"
PULASKI = "155"
RADFORD_CITY = "750"
RAPPAHANNOCK = "157"
RICHMOND = "159"
RICHMOND_CITY = "760"
ROANOKE = "161"
ROANOKE_CITY = "770"
ROCKBRIDGE = "163"
ROCKINGHAM = "165"
RUSSELL = "167"
SALEM_CITY = "775"
SCOTT = "169"
SHENANDOAH = "171"
SMYTH = "173"
SOUTHAMPTON = "175"
SPOTSYLVANIA = "177"
STAFFORD = "179"
STAUNTON_CITY = "790"
SUFFOLK_CITY = "800"
SURRY = "181"
SUSSEX = "183"
TAZEWELL = "185"
VIRGINIA_BEACH_CITY = "810"
WARREN = "187"
WASHINGTON = "191"
WAYNESBORO_CITY = "820"
WESTMORELAND = "193"
WILLIAMSBURG_CITY = "830"
WINCHESTER_CITY = "840"
WISE = "195"
WYTHE = "197"
YORK = "199"



# Copyright (c) 2022 Darren Erik Vengroff
"""A variable source that loads metadata about variables from the U.S. Census API."""

from typing import Any, Dict, List, Optional

from censusdis.impl.fetch import json_from_url
from censusdis.impl.varsource.base import VariableSource


class CensusApiVariableSource(VariableSource):
    """
    A :py:class:`~VariableSource` that gets data from the US Census remote API.

    Users will rarely if ever need to explicitly construct objects
    of this class. There is one behind the singleton cache
    `censusdis.censusdata.variables`.
    """

    @staticmethod
    def _url_part(dataset: str, year: int):
        if not isinstance(year, int):
            return f"{dataset}"

        return f"{year}/{dataset}"

    @staticmethod
    def variables_url(dataset: str, year: int, response_format: str = "json") -> str:
        """
        Construct the URL to fetch metadata about all variables.

        Parameters
        ----------
        dataset
            The census dataset.
        year
            The year
        response_format
            The desired format of the response. Either `json` (the default)
            or `html`.

        Returns
        -------
            The URL to fetch the metadata from.

        """
        return (
            f"https://api.census.gov/data/{CensusApiVariableSource._url_part(dataset, year)}/"
            f"variables.{response_format}"
        )

    @staticmethod
    def url(dataset: str, year: int, name: str, response_format: str = "json") -> str:
        """
        Construct the URL to fetch metadata about a variable.

        This is where we fetch metadata that is then put into the
        local cache.

        Parameters
        ----------
        dataset
            The census dataset.
        year
            The year
        name
            The name of the variable.
        response_format
            The desired format of the response. Either `json` (the default)
            or `html`.

        Returns
        -------
            The URL to fetch the metadata from.
        """
        return (
            f"https://api.census.gov/data/{CensusApiVariableSource._url_part(dataset, year)}/"
            f"variables/{name}.{response_format}"
        )

    @staticmethod
    def group_url(
        dataset: str,
        year: int,
        group_name: Optional[str] = None,
    ) -> str:
        """
        Get the URL to fetch metadata about a group of variables.

        This can either be all the variables in a dataset, if a group
        name is not specified, or just the variables in a particular
        group if the data set has groups.

        Some datasets, `dec/pl` dataset for example, do not have
        groups, so a group name need not be passed. Others, like
        `acs/acs5` have groups, so a group name such as `B01001`
        will normally be passed in.

        Parameters
        ----------
        dataset
            The census dataset.
        year
            The year
        group_name
            The name of the group, or `None` if the dataset has no
            groups.

        Returns
        -------
            The URL to fetch the metadata from.
        """
        if group_name is None:
            return f"https://api.census.gov/data/{CensusApiVariableSource._url_part(dataset, year)}/variables.json"

        return (
            f"https://api.census.gov/data/{CensusApiVariableSource._url_part(dataset, year)}/"
            f"groups/{group_name}.json"
        )

    @staticmethod
    def all_groups_url(dataset: str, year: int) -> str:
        """
        Get the URL to fetch the names of all groups.

        Parameters
        ----------
        dataset
            The census dataset.
        year
            The year

        Returns
        -------
            The URL to fetch the metadata from.
        """
        return f"https://api.census.gov/data/{CensusApiVariableSource._url_part(dataset, year)}/groups.json"

    def get(self, dataset: str, year: int, name: str) -> Dict[str, Any]:
        """Get info on a dataset via a remote query to the U.S. Census API."""
        url = self.url(dataset, year, name)
        value = json_from_url(url)

        return value

    def get_group(
        self, dataset: str, year: int, name: Optional[str]
    ) -> Dict[str, Dict]:
        """Get info on the groups in a dataset via a remote query to the U.S. Census API."""
        url = self.group_url(dataset, year, name)
        value = json_from_url(url)

        # Filter out psuedo-variables like 'for' and 'in'.
        value["variables"] = {
            k: v
            for k, v in value["variables"].items()
            if k not in ["in", "for", "ucgid"]
        }

        # Put the name into the nested dictionaries, so it looks the same is if
        # we had gotten it via the variable API even though that API leaves it out.
        for k, val in value["variables"].items():
            val["name"] = k

        return value

    def get_all_groups(self, dataset: str, year: int) -> Dict[str, List]:
        """Get info on all the groups in a dataset via a remote query to the U.S. Census API."""
        url = self.all_groups_url(dataset, year)
        value = json_from_url(url)

        return value

    def get_datasets(self, year: Optional[int]) -> Dict[str, Any]:
        """Get info on all the datasets for a given year via a remote query to the U.S. Census API."""
        if year is not None:
            url = f"https://api.census.gov/data/{year}.json"
        else:
            url = "https://api.census.gov/data.json"

        json = json_from_url(url)

        return json



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Kentucky."""


ADAIRVILLE_CITY = "00298"
AGES_CDP = "00514"
ALBANY_CITY = "00694"
ALEXANDRIA_CITY = "00802"
ALLEN_CITY = "00946"
ALLENSVILLE_CDP = "01000"
ANCHORAGE_CITY = "01504"
ANNVILLE_CDP = "01648"
ANTHOSTON_CDP = "01720"
ARJAY_CDP = "01972"
ARLINGTON_CITY = "02044"
ARTEMUS_CDP = "02188"
ASHLAND_CITY = "02368"
AUBURN_CITY = "02638"
AUDUBON_PARK_CITY = "02656"
AUGUSTA_CITY = "02674"
AUXIER_CDP = "02764"
BANCROFT_CITY = "03376"
BANDANA_CDP = "03412"
BARBOURMEADE_CITY = "03556"
BARBOURVILLE_CITY = "03574"
BARDSTOWN_CITY = "03628"
BARDWELL_CITY = "03664"
BARLOW_CITY = "03718"
BEATTYVILLE_CITY = "04546"
BEAVER_DAM_CITY = "04654"
BEDFORD_CITY = "04816"
BEECH_GROVE_CDP = "04978"
BEECHMONT_CDP = "05014"
BEECHWOOD_VILLAGE_CITY = "05068"
BELFRY_CDP = "05266"
BELLEFONTE_CITY = "05374"
BELLEMEADE_CITY = "05392"
BELLEVIEW_CDP = "05428"
BELLEVUE_CITY = "05446"
BELLEWOOD_CITY = "05464"
BENHAM_CITY = "05662"
BENTON_CITY = "05824"
BEREA_CITY = "05842"
BERRY_CITY = "05968"
BETSY_LAYNE_CDP = "06220"
BIG_CLIFTY_CDP = "06508"
BLACKEY_CITY = "07012"
BLAINE_CITY = "07264"
BLANDVILLE_CITY = "07390"
BLOOMFIELD_CITY = "07516"
BLUE_RIDGE_MANOR_CITY = "07858"
BONNIEVILLE_CITY = "08488"
BOONEVILLE_CITY = "08614"
BOSTON_CDP = "08722"
BOWLING_GREEN_CITY = "08902"
BRADFORDSVILLE_CITY = "09100"
BRANDENBURG_CITY = "09226"
BRECKINRIDGE_CENTER_CDP = "09379"
BREMEN_CITY = "09406"
BRIARWOOD_CITY = "09532"
BRODHEAD_CITY = "09838"
BROECK_POINTE_CITY = "09847"
BROMLEY_CITY = "09856"
BROOKS_CDP = "09964"
BROOKSVILLE_CITY = "10000"
BROWNSBORO_FARM_CITY = "10162"
BROWNSBORO_VILLAGE_CITY = "10198"
BROWNSVILLE_CITY = "10324"
BUCKHORN_CITY = "10612"
BUCKNER_CDP = "10648"
BUFFALO_CDP = "10774"
BURGIN_CITY = "11044"
BURKESVILLE_CITY = "11098"
BURLINGTON_CDP = "11170"
BURNA_CDP = "11188"
BURNSIDE_CITY = "11278"
BUTLER_CITY = "11530"
CADIZ_CITY = "11692"
CALHOUN_CITY = "11854"
CALIFORNIA_CITY = "11872"
CALVERT_CITY_CITY = "12016"
CAMARGO_CITY = "12052"
CAMBRIDGE_CITY = "12066"
CAMPBELLSBURG_CITY = "12142"
CAMPBELLSVILLE_CITY = "12160"
CAMPTON_CITY = "12358"
CANEYVILLE_CITY = "12538"
CANNONSBURG_CDP = "12610"
CARLISLE_CITY = "12898"
CARROLLTON_CITY = "13024"
CARRSVILLE_CITY = "13060"
CATLETTSBURG_CITY = "13420"
CAVE_CITY_CITY = "13492"
CAWOOD_CDP = "13582"
CAYCE_CDP = "13600"
CECILIA_CDP = "13636"
CENTERTOWN_CITY = "13870"
CENTRAL_CITY_CITY = "13978"
CERULEAN_CDP = "14068"
CHAPLIN_CDP = "14266"
CLARKSON_CITY = "15148"
CLARYVILLE_CDP = "15166"
CLAY_CITY_CITY = "15238"
CLAY_CITY = "15202"
CLEATON_CDP = "15490"
CLINTON_CITY = "15742"
CLOVERPORT_CITY = "15904"
COAL_RUN_VILLAGE_CITY = "16110"
COLD_SPRING_CITY = "16372"
COLDIRON_CDP = "16354"
COLDSTREAM_CITY = "16395"
COLUMBIA_CITY = "16750"
COLUMBUS_CITY = "16768"
COMBS_CDP = "16822"
CONCORD_CITY = "16894"
CORBIN_CITY = "17362"
CORINTH_CITY = "17434"
CORYDON_CITY = "17686"
COVINGTON_CITY = "17848"
COXTON_CDP = "17938"
CRAB_ORCHARD_CITY = "17956"
CRAYNE_CDP = "18190"
CREEKSIDE_CITY = "18270"
CRESCENT_SPRINGS_CITY = "18352"
CRESTVIEW_HILLS_CITY = "18442"
CRESTVIEW_CITY = "18424"
CRESTWOOD_CITY = "18496"
CRITTENDEN_CITY = "18568"
CROFTON_CITY = "18658"
CROSSGATE_CITY = "18766"
CUMBERLAND_CITY = "19108"
CUNNINGHAM_CDP = "19234"
CURDSVILLE_CDP = "19288"
CYNTHIANA_CITY = "19432"
DANVILLE_CITY = "19882"
DAWSON_SPRINGS_CITY = "20224"
DAYTON_CITY = "20350"
DEXTER_CDP = "21322"
DIABLOCK_CDP = "21358"
DIXON_CITY = "21682"
DOE_VALLEY_CDP = "21844"
DOUGLASS_HILLS_CITY = "22204"
DOVER_CITY = "22222"
DRAKESBORO_CITY = "22348"
DRUID_HILLS_CITY = "22474"
DRY_RIDGE_CITY = "22582"
DUNMOR_CDP = "23014"
DWALE_CDP = "23104"
EARLINGTON_CITY = "23230"
EAST_BERNSTADT_CDP = "23284"
EDDYVILLE_CITY = "23824"
EDGEWOOD_CITY = "23932"
EDMONTON_CITY = "23968"
EKRON_CITY = "24094"
ELIZABETHTOWN_CITY = "24274"
ELIZAVILLE_CDP = "24292"
ELK_CREEK_CDP = "24328"
ELKHORN_CITY_CITY = "24382"
ELKTON_CITY = "24400"
ELSMERE_CITY = "24778"
EMINENCE_CITY = "24904"
EMLYN_CDP = "24922"
ERLANGER_CITY = "25300"
EUBANK_CITY = "25552"
EVARTS_CITY = "25606"
EWING_CITY = "25786"
EZEL_CDP = "25876"
FAIRFIELD_CITY = "26020"
FAIRVIEW_CDP = "26182"
FAIRVIEW_CITY = "26236"
FALMOUTH_CITY = "26434"
FANCY_FARM_CDP = "26452"
FARLEY_CDP = "26528"
FARMERS_CDP = "26560"
FARMINGTON_CDP = "26614"
FERGUSON_CITY = "27010"
FINCASTLE_CITY = "27262"
FLAT_LICK_CDP = "27730"
FLATWOODS_CITY = "27802"
FLEMING_NEON_CITY = "27846"
FLEMINGSBURG_CITY = "27856"
FLORENCE_CITY = "27982"
FORDSVILLE_CITY = "28270"
FOREST_HILLS_CITY = "28342"
FORT_CAMPBELL_NORTH_CDP = "28486"
FORT_KNOX_CDP = "28540"
FORT_MITCHELL_CITY = "28558"
FORT_THOMAS_CITY = "28594"
FORT_WRIGHT_CITY = "28612"
FOUNTAIN_RUN_CITY = "28666"
FOX_CHASE_CITY = "28785"
FRANCISVILLE_CDP = "28882"
FRANKFORT_CITY = "28900"
FRANKLIN_CITY = "28918"
FREDONIA_CITY = "29080"
FREEBURN_CDP = "29134"
FRENCHBURG_CITY = "29260"
FULTON_CITY = "29566"
GAMALIEL_CITY = "29872"
GARRISON_CDP = "30232"
GEORGETOWN_CITY = "30700"
GERMANTOWN_CITY = "30718"
GHENT_CITY = "30808"
GILBERTSVILLE_CDP = "30880"
GLASGOW_CITY = "31114"
GLENCOE_CITY = "31204"
GLENVIEW_HILLS_CITY = "31402"
GLENVIEW_MANOR_CITY = "31420"
GLENVIEW_CITY = "31348"
GOOSE_CREEK_CITY = "31870"
GOSHEN_CITY = "31960"
GRACEY_CDP = "32032"
GRAND_RIVERS_CITY = "32212"
GRATZ_CITY = "32428"
GRAYMOOR_DEVONDALE_CITY = "32523"
GRAYSON_CITY = "32572"
GREEN_SPRING_CITY = "32986"
GREENSBURG_CITY = "32968"
GREENUP_CITY = "33004"
GREENVILLE_CITY = "33022"
GUTHRIE_CITY = "33562"
HANSON_CITY = "34390"
HARDIN_CITY = "34534"
HARDINSBURG_CITY = "34552"
HARDYVILLE_CDP = "34660"
HARLAN_CITY = "34732"
HARRODSBURG_CITY = "34966"
HARTFORD_CITY = "35020"
HAWESVILLE_CITY = "35200"
HAZARD_CITY = "35362"
HAZEL_GREEN_CDP = "35398"
HAZEL_CITY = "35380"
HEBRON_CDP = "35542"
HEBRON_ESTATES_CITY = "35545"
HENDERSON_CITY = "35866"
HENDRON_CDP = "35902"
HERITAGE_CREEK_CITY = "36102"
HICKMAN_CITY = "36298"
HICKORY_CDP = "36316"
HICKORY_HILL_CITY = "36374"
HIGH_BRIDGE_CDP = "36460"
HIGHLAND_HEIGHTS_CITY = "36604"
HILLS_AND_DALES_CITY = "36865"
HILLVIEW_CITY = "36982"
HINDMAN_CITY = "37108"
HISEVILLE_CDP = "37234"
HODGENVILLE_CITY = "37396"
HOLLOW_CREEK_CITY = "37576"
HOLLYVILLA_CITY = "37630"
HOPKINSVILLE_CITY = "37918"
HORSE_CAVE_CITY = "38008"
HOUSTON_ACRES_CITY = "38170"
HUNTERS_HOLLOW_CITY = "38670"
HURSTBOURNE_ACRES_CITY = "38818"
HURSTBOURNE_CITY = "38814"
HUSTONVILLE_CITY = "38836"
HYDEN_CITY = "38908"
INDEPENDENCE_CITY = "39142"
INDIAN_HILLS_CITY = "39304"
INEZ_CITY = "39430"
IRONVILLE_CDP = "39592"
IRVINE_CITY = "39646"
IRVINGTON_CITY = "39664"
ISLAND_CITY = "39700"
JACKSON_CITY = "39952"
JAMESTOWN_CITY = "40114"
JEFF_CDP = "40204"
JEFFERSONTOWN_CITY = "40222"
JEFFERSONVILLE_CITY = "40240"
JENKINS_CITY = "40312"
JUNCTION_CITY_CITY = "41338"
KEENE_CITY = "41716"
KENTON_VALE_CITY = "42094"
KENVIR_CDP = "42112"
KEVIL_CITY = "42292"
KINGSLEY_CITY = "42598"
KNOTTSVILLE_CDP = "43030"
KUTTAWA_CITY = "43264"
LA_CENTER_CITY = "43336"
LA_GRANGE_CITY = "43480"
LAFAYETTE_CITY = "43444"
LAKESIDE_PARK_CITY = "43606"
LAKEVIEW_HEIGHTS_CITY = "43668"
LANCASTER_CITY = "43840"
LANGDON_PLACE_CITY = "43900"
LAWRENCEBURG_CITY = "44146"
LEBANON_JUNCTION_CITY = "44362"
LEBANON_CITY = "44344"
LEDBETTER_CDP = "44434"
LEITCHFIELD_CITY = "44686"
LEWISBURG_CITY = "45064"
LEWISPORT_CITY = "45136"
LEXINGTON_FAYETTE_URBAN_COUNTY = "46027"
LIBERTY_CITY = "46072"
LINCOLNSHIRE_CITY = "46540"
LIVERMORE_CITY = "47062"
LIVINGSTON_CITY = "47098"
LONDON_CITY = "47476"
LORETTO_CITY = "47710"
LOUISA_CITY = "47854"
LOUISVILLE_JEFFERSON_COUNTY_METRO_GOVERNMENT_BALANCE = "48006"
LOVELACEVILLE_CDP = "48072"
LOWES_CDP = "48234"
LOYALL_CITY = "48288"
LUDLOW_CITY = "48378"
LYNCH_CITY = "48540"
LYNDON_CITY = "48558"
LYNNVIEW_CITY = "48648"
MACEO_CDP = "49026"
MACKVILLE_CITY = "49206"
MADISONVILLE_CITY = "49368"
MAGNOLIA_CDP = "49476"
MANCHESTER_CITY = "49656"
MANITOU_CDP = "49746"
MANOR_CREEK_CITY = "49800"
MARION_CITY = "50034"
MARROWBONE_CDP = "50124"
MARTIN_CITY = "50286"
MARYHILL_ESTATES_CITY = "50412"
MASONVILLE_CDP = "50520"
MASSAC_CDP = "50556"
MAYFIELD_CITY = "50898"
MAYKING_CDP = "50952"
MAYS_LICK_CDP = "51006"
MAYSVILLE_CITY = "51024"
MAYTOWN_CDP = "51042"
MCCARR_CDP = "48810"
MCDOWELL_CDP = "48954"
MCHENRY_CITY = "49098"
MCKEE_CITY = "49116"
MCKINNEY_CDP = "49134"
MCROBERTS_CDP = "49278"
MEADOW_VALE_CITY = "51258"
MEADOWBROOK_FARM_CITY = "51193"
MEADOWVIEW_ESTATES_CITY = "51294"
MELBOURNE_CITY = "51438"
MENTOR_CITY = "51564"
MIDDLESBOROUGH_CITY = "51924"
MIDDLETOWN_CITY = "51978"
MIDWAY_CITY = "52140"
MILLERSBURG_CITY = "52302"
MILLSTONE_CDP = "52464"
MILTON_CITY = "52590"
MOCKINGBIRD_VALLEY_CITY = "52842"
MONTEREY_CITY = "53076"
MONTICELLO_CITY = "53130"
MOORLAND_CITY = "53328"
MOREHEAD_CITY = "53418"
MORGANFIELD_CITY = "53472"
MORGANTOWN_CITY = "53490"
MORTONS_GAP_CITY = "53616"
MOSELEYVILLE_CDP = "53670"
MOUNT_OLIVET_CITY = "53976"
MOUNT_STERLING_CITY = "54084"
MOUNT_VERNON_CITY = "54174"
MOUNT_WASHINGTON_CITY = "54228"
MULDRAUGH_CITY = "54480"
MUNFORDVILLE_CITY = "54570"
MURRAY_HILL_CITY = "54660"
MURRAY_CITY = "54642"
NEBO_CITY = "55092"
NEW_CASTLE_CITY = "55596"
NEW_HAVEN_CITY = "55758"
NEW_HOPE_CDP = "55794"
NEWPORT_CITY = "55884"
NICHOLASVILLE_CITY = "56136"
NORBOURNE_ESTATES_CITY = "56550"
NORTH_CORBIN_CDP = "56694"
NORTH_MIDDLETOWN_CITY = "56820"
NORTHFIELD_CITY = "56730"
NORTONVILLE_CITY = "56910"
NORWOOD_CITY = "56928"
OAK_GROVE_CITY = "57090"
OAKBROOK_CDP = "57030"
OAKLAND_CITY = "57144"
OLD_BROWNSBORO_PLACE_CITY = "57658"
OLIVE_HILL_CITY = "57918"
ONEIDA_CDP = "58062"
ONTON_CDP = "58116"
ORCHARD_GRASS_HILLS_CITY = "58200"
OWENSBORO_CITY = "58620"
OWENTON_CITY = "58692"
OWINGSVILLE_CITY = "58710"
PADUCAH_CITY = "58836"
PAINTSVILLE_CITY = "58962"
PANTHER_CDP = "59124"
PARIS_CITY = "59196"
PARK_CITY_CITY = "59232"
PARK_HILLS_CITY = "59255"
PARKWAY_VILLAGE_CITY = "59322"
PATHFORK_CDP = "59466"
PAYNE_GAP_CDP = "59592"
PEMBROKE_CITY = "59934"
PERRYVILLE_CITY = "60258"
PETERSBURG_CDP = "60312"
PEWEE_VALLEY_CITY = "60492"
PHELPS_CDP = "60600"
PHILPOT_CDP = "60654"
PIKEVILLE_CITY = "60852"
PINE_KNOT_CDP = "61122"
PINEVILLE_CITY = "61248"
PIONEER_VILLAGE_CITY = "61356"
PIPPA_PASSES_CITY = "61374"
PLANO_CDP = "61536"
PLANTATION_CITY = "61554"
PLEASANT_RIDGE_CDP = "61680"
PLEASANT_VIEW_CDP = "61734"
PLEASUREVILLE_CITY = "61788"
PLUM_SPRINGS_CITY = "61860"
POOLE_CDP = "62202"
POPLAR_HILLS_CITY = "62370"
POWDERLY_CITY = "62652"
PRESTONSBURG_CITY = "62940"
PRESTONVILLE_CITY = "62958"
PRINCETON_CITY = "63138"
PROSPECT_CITY = "63264"
PROVIDENCE_CITY = "63372"
PRYORSBURG_CDP = "63426"
RABBIT_HASH_CDP = "63804"
RACELAND_CITY = "63858"
RADCLIFF_CITY = "63912"
RAVENNA_CITY = "64092"
RAYWICK_CITY = "64146"
REIDLAND_CDP = "64632"
RICHLAWN_CITY = "65208"
RICHMOND_CITY = "65226"
RINEYVILLE_CDP = "65388"
RIVER_BLUFF_CITY = "65559"
RIVERWOOD_CITY = "65766"
ROBARDS_CITY = "65874"
ROCHESTER_CITY = "65982"
ROCKHOLDS_CDP = "66162"
ROCKPORT_CITY = "66216"
ROLLING_FIELDS_CITY = "66486"
ROLLING_HILLS_CITY = "66504"
ROSINE_CDP = "66846"
RUSSELL_SPRINGS_CITY = "67494"
RUSSELL_CITY = "67458"
RUSSELLVILLE_CITY = "67512"
RYLAND_HEIGHTS_CITY = "67602"
SACRAMENTO_CITY = "67638"
SADIEVILLE_CITY = "67656"
SALEM_CITY = "68052"
SALT_LICK_CITY = "68160"
SALVISA_CDP = "68214"
SALYERSVILLE_CITY = "68232"
SANDERS_CITY = "68358"
SANDY_HOOK_CITY = "68556"
SARDIS_CITY = "68646"
SCIENCE_HILL_CITY = "68952"
SCOTTSVILLE_CITY = "69114"
SEBREE_CITY = "69222"
SEDALIA_CDP = "69258"
SENECA_GARDENS_CITY = "69384"
SHARPSBURG_CITY = "69852"
SHELBYVILLE_CITY = "70050"
SHEPHERDSVILLE_CITY = "70086"
SHIVELY_CITY = "70284"
SILVER_GROVE_CITY = "70644"
SIMPSONVILLE_CITY = "70752"
SLAUGHTERS_CITY = "71130"
SMITHFIELD_CITY = "71364"
SMITHLAND_CITY = "71382"
SMITHS_GROVE_CITY = "71454"
SOMERSET_CITY = "71688"
SONORA_CITY = "71724"
SORGHO_CDP = "71760"
SOUTH_CARROLLTON_CITY = "71814"
SOUTH_PARK_VIEW_CITY = "72138"
SOUTH_SHORE_CITY = "72210"
SOUTH_WALLINS_CDP = "72255"
SOUTH_WILLIAMSON_CDP = "72264"
SOUTHGATE_CITY = "71976"
SPARTA_CITY = "72372"
SPOTTSVILLE_CDP = "72570"
SPRING_MILL_CITY = "72770"
SPRING_VALLEY_CITY = "72790"
SPRINGFIELD_CITY = "72660"
ST_CHARLES_CITY = "67710"
ST_JOSEPH_CDP = "67854"
ST_MARY_CITY = "67890"
ST_MATTHEWS_CITY = "67944"
ST_REGIS_PARK_CITY = "67998"
STAMPING_GROUND_CITY = "73038"
STANFORD_CITY = "73110"
STANLEY_CDP = "73146"
STANTON_CITY = "73164"
STEARNS_CDP = "73362"
STRATHMOOR_MANOR_CITY = "74064"
STRATHMOOR_VILLAGE_CITY = "74082"
STURGIS_CITY = "74316"
SUMMER_SHADE_CDP = "74586"
SUMMERSVILLE_CDP = "74604"
SYCAMORE_CITY = "75190"
SYMSONIA_CDP = "75270"
TAYLOR_MILL_CITY = "75738"
TAYLORSVILLE_CITY = "75810"
TEN_BROECK_CITY = "75963"
THORNHILL_CITY = "76380"
THRUSTON_CDP = "76620"
TOLU_CDP = "77124"
TOMPKINSVILLE_CITY = "77160"
TRENTON_CITY = "77592"
UNION_CITY = "78384"
UNIONTOWN_CITY = "78492"
UPTON_CITY = "78672"
UTICA_CDP = "78708"
VAN_LEAR_CDP = "79194"
VANCEBURG_CITY = "79068"
VERONA_CDP = "79464"
VERSAILLES_CITY = "79482"
VICCO_CITY = "79590"
VILLA_HILLS_CITY = "79698"
VINE_GROVE_CITY = "79734"
VIRGIE_CDP = "79860"
WALLINS_CREEK_CDP = "80310"
WALTON_CITY = "80490"
WARFIELD_CITY = "80616"
WARSAW_CITY = "80706"
WATER_VALLEY_CDP = "80832"
WATTERSON_PARK_CITY = "80913"
WAVERLY_CITY = "80958"
WAYLAND_CITY = "81012"
WELLINGTON_CITY = "81372"
WEST_BUECHEL_CITY = "81624"
WEST_LIBERTY_CITY = "81858"
WEST_LOUISVILLE_CDP = "81876"
WEST_POINT_CITY = "81930"
WEST_VAN_LEAR_CDP = "82056"
WESTPORT_CDP = "81948"
WESTWOOD_CDP = "82146"
WESTWOOD_CITY = "82164"
WHEATCROFT_CITY = "82200"
WHEELWRIGHT_CITY = "82272"
WHITE_PLAINS_CITY = "82722"
WHITESBURG_CITY = "82776"
WHITESVILLE_CITY = "82830"
WHITLEY_CITY_CDP = "82938"
WICKLIFFE_CITY = "83064"
WILDER_CITY = "83172"
WILDWOOD_CITY = "83208"
WILLIAMSBURG_CITY = "83334"
WILLIAMSTOWN_CITY = "83406"
WILLISBURG_CITY = "83424"
WILMORE_CITY = "83550"
WINCHESTER_CITY = "83676"
WINDY_HILLS_CITY = "83784"
WINGO_CITY = "83856"
WOODBURN_CITY = "84414"
WOODBURY_CITY = "84432"
WOODLAND_HILLS_CITY = "84486"
WOODLAWN_PARK_CITY = "84576"
WOODLAWN_CITY = "84522"
WORTHINGTON_HILLS_CITY = "84891"
WORTHINGTON_CITY = "84864"
WORTHVILLE_CITY = "84900"
WURTLAND_CITY = "85008"
YELVINGTON_CDP = "85224"
